//----------------------------------------------------------------------
// Module    	: 	ERM19296-1 Series
// Create    	: 	JAVEN LIU
// Date      	: 	2023-06-02
// Drive IC  	: 	ST75256
// INTERFACE 	: 	I2C
// MCU 	 		: 	ST12LE5A60S2
// VDD		 	: 	3.3V       
//----------------------------------------------------------------------

#include <STC12C5A.H>  
#include <intrins.h>

#define uint unsigned int
#define uchar unsigned char

#define Write_Address 0x7E	 //CS1 MUST Connected LOW	 SA0=1,SA1=1


//LCD IO		
sbit RESET       =             P3^4;
sbit SDA	=		P1^1;
sbit SCL	=		P1^0;

//KEY Adjust contrast
sbit key_add=P0^1;
sbit key_dec=P0^2;
sbit pause=P3^2;
bit log=0;

uchar mode=0; //1 Gray  0:Mono	
uchar	 SIZE;

//ERC19296FS-1
uint Contrast=202;  

//ERC19296SG-1
//uint Contrast=220;  

void Delay(uint n);
void delay_ms(uint Delay);
void display_Contrast(uint number);
void adj_Contrast(void);
	
void Set_Contrast_Control_Register(unsigned int mod);
void Set_Column_Address(unsigned char add);
void Set_Page_Address(unsigned char add);
void Write_Data(unsigned char dat);
void Write_Instruction(unsigned char cmd);
void Initial(void);	
void ClearScreen(void);

void ShowChar(unsigned char x,unsigned char y,unsigned char chr);
void ShowNum(unsigned char x,unsigned char y,unsigned int  num,unsigned char len,unsigned char size2);
void ShowString(unsigned char x,unsigned char y, unsigned char *p);	 

void Set_Pos(unsigned char xs, unsigned char ys,unsigned char xe,unsigned char ye) ;
void ShowCHinese(unsigned char x,unsigned char y,unsigned char no);
void DrawBMP(unsigned char x0, unsigned char y0,unsigned char x1, unsigned char y1,unsigned char BMP[]);												 
void Show_line_dot();
void Show(unsigned char d1,unsigned char d2);


const unsigned char code  F6x8[][6];
const unsigned char code F8X16[];
unsigned char code Hzk[];
unsigned char code pic1[];
unsigned char code pic2[];
unsigned char code pic3[];
unsigned char code pic4[];





void main(void)
{

 	P1M1=0x00; //Set P1 port as push-pull output
	P1M0=0xff;

 	P3M1=0x00; //Set P3 port as push-pull output
 	P3M0=0xFF;
   
	P0=0xff; P1=0xff;P2=0xff;P3=0xff;

	IE=0x81;
	IP=0x01;
	TCON=0x01;

	delay_ms(100);
    Initial();

	while(1)
	{
		Write_Instruction(0xf0);   // Display Mode
		Write_Data(0x10);		   // Monochrome Mode
	   	mode=0;
		 ClearScreen();
		
		ShowCHinese(32,0,0);
		ShowCHinese(48,0,1);
		ShowCHinese(64,0,2);
		ShowCHinese(80,0,3);
		ShowCHinese(96,0,4);
		ShowCHinese(112,0,5);  
		ShowCHinese(128,0,6); 
 		ShowCHinese(144,0,7); 

		ShowCHinese(48,3,8);
		ShowCHinese(64,3,9);  
		ShowCHinese(80,3,12); 
 		ShowCHinese(96,3,13); 
		ShowCHinese(112,3,14); 
 		ShowCHinese(128,3,15); 			 

		SIZE=16;
		ShowString(10,6,"www,buydisplay.com");
		SIZE=8;
	 	ShowString(0,9,"EastRising Technology.LT");  
 	 	ShowString(40,11,"Hollw!World!"); 
		delay_ms(2000);

		
 // 		Show_line_dot();
 
 	
	   	ClearScreen();	 
		

		DrawBMP(0,0,192,12,pic1); //x:0,y:0,col:192,line:12*8=96 	 
		delay_ms(2000);
//	    Write_Instruction(0xa7);  //Set  inverse  display 	 
//		delay_ms(1000);
//	    Write_Instruction(0xa6);  //Set normal display 


		DrawBMP(0,0,192,12,pic2);  //x:0,y:0,col:192,line:12*8=96 
		delay_ms(2000);
// 	    Write_Instruction(0xa7);  //Set  inverse  display 	 
//		delay_ms(1000);
//	    Write_Instruction(0xa6);  //Set normal display 


		DrawBMP(0,0,192,12,pic3);  //x:0,y:0,col:192,line:12*8=96 
		delay_ms(2000);
 //	    Write_Instruction(0xa7);  //Set  inverse  display 	 
//		delay_ms(1000);
//	    Write_Instruction(0xa6);  //Set normal display 




		 Write_Instruction(0xf0);   // Display Mode
	     Write_Data(0x11);		   // 4Gray  Mode
		 mode=1;
		DrawBMP(0,0,192,24,pic4);  //x:0,y:0,col:192,line:24*4=96 
		delay_ms(2000);
 //	    Write_Instruction(0xa7);  //Set  inverse  display 	 
//		delay_ms(1000);
//	    Write_Instruction(0xa6);  //Set normal display 




	}
}






void Delay(uint n)
{ unsigned int i;
while(n--)
  {  
   for(i=0;i<400;i++) 
     {;} 

   }
}


void delay_ms(uint Delay)
{unsigned int i; 
while(Delay)
  {
   for(;Delay>0;Delay--) 
   {  
    for(i=0;i<1000;i++) 
        {;}   
    if((key_add==0)||(key_dec==0)) adj_Contrast();	     			
   }
  
	for(;log==1;);
  }

	return;
}




void Step(void) interrupt 0 using 0
{  ET0=0;
 // Delay(3);
//	if(pause==0)
	log=!log;

   while(!pause);
     ET0=1;
  return;

}




void display_Contrast(uint number)
{	uchar number1,number2,number3; uchar value[10] = {'0', '1', '2', '3', '4', '5', '6', '7', '8', '9'};
	number1=number/100;number2=number%100/10;number3=number%100%10;
	ShowChar(0,0,value[number1]) ;
	ShowChar(6,0,value[number2]) ;
 	ShowChar(12,0,value[number3]) ;
}



void adj_Contrast(void)
{	
 	 if((key_add==0)||(key_dec==0))
		{		
		 if	(key_add==0) 
			{
			Contrast+=1;//if(Contrast==0x3f)(Contrast=0);
		   	Set_Contrast_Control_Register(Contrast);	
			display_Contrast(Contrast);
			Delay(300);
			if(key_add==0)
				{Delay(300);
					if(key_add==0)			
						{Delay(300);
							if(key_add==0)
								{Delay(300);
									if(key_add==0)

										{while(key_add==0)
											{
											Contrast+=1; //if(Contrast>0x3f)(Contrast=0);
		   										Set_Contrast_Control_Register(Contrast);	
												display_Contrast(Contrast);
							 					Delay(300); 
											}
										}
								}				
						}						
				}												
			}
	


		  
	
		 if	(key_dec==0) 
			{
			Contrast-=1; //if((Contrast<=0xff)&&(Contrast>0x3f))(Contrast=0x3f);
		   	Set_Contrast_Control_Register(Contrast);	
			display_Contrast(Contrast);
			Delay(300);
			if(key_dec==0)
				{Delay(300);
					if(key_dec==0)			
						{Delay(300);
							if(key_dec==0)
								{Delay(300);
									if(key_dec==0)

										{while(key_dec==0)
											{
											Contrast-=1;// if((Contrast<=0xff)&&(Contrast>0x3f))(Contrast=0x3f);
		   										Set_Contrast_Control_Register(Contrast);	
												display_Contrast(Contrast);
							 					Delay(300); 
											}
										}
								}				
						}						
				}												
			}

	  	}
}




 
void Send_Byte(uchar dat)
{
	uchar i;
	for(i=0;i<8;i++)
	{
		SCL=0;
		if(dat&0x80)
		{
			SDA=1;
		}
		else
		{
			SDA=0;
		}
		_nop_();
		_nop_(); 
	 	_nop_();
		_nop_();
		SCL=1;
		_nop_();
		_nop_(); 
	 	_nop_();
		_nop_();
		SCL=0;
		dat<<=1;
	}
}

//ʼź
void I2C_Start(void)
{
	SDA=1;
	SCL=1;
	_nop_();
	_nop_(); 
 	_nop_();
	_nop_();
	SDA=0;
	_nop_();
	_nop_(); 
 	_nop_();
	_nop_();
	SCL=0;
	 
}

//ź
void I2C_Stop(void)
{
	SDA=0;
	SCL=1;
	_nop_();
	_nop_(); 
 	_nop_();
	_nop_();
	SDA=1;
}

//ȴźӦ
void I2C_WaitAck(void) //źŵĵƽ
{
	SDA=1;
	_nop_();
	_nop_(); 
 	_nop_();
	_nop_();
	SCL=1;
	_nop_();
	_nop_(); 
 	_nop_();
	_nop_();
	SCL=0;
	_nop_();
	_nop_(); 
 	_nop_();
	_nop_();
}


void Write_Instruction(unsigned char cmd)
{
	I2C_Start();
	Send_Byte(Write_Address);
	I2C_WaitAck();
 	Send_Byte(0x00);
	I2C_WaitAck();
	Send_Byte(cmd);
	I2C_WaitAck();
	I2C_Stop();
}


void Write_Data(unsigned char Data)
{
	I2C_Start();
	Send_Byte(Write_Address);
	I2C_WaitAck(); 
 	Send_Byte(0x40);
	I2C_WaitAck();
	Send_Byte(Data);
	I2C_WaitAck();
	I2C_Stop();
}






void Initial(void)
{

	RESET =1;
	delay_ms(10);
	RESET =0;
	delay_ms(10);
	RESET =1;
	delay_ms(10);


 	Write_Instruction(0x30);	// Extension Command 1

 	Write_Instruction(0x94);	// Sleep Out
 	delay_ms(50);
 	Write_Instruction(0x31); // Extension Command 2
 	Write_Instruction(0x32);// Analog Circuit Set
	Write_Data(0x00);
	Write_Data(0x01);
	Write_Data(0x03);
  	Write_Instruction(0x51);  // Booster Level x10

	Write_Data(0xFA);		   //8X


  	Write_Instruction(0x30);	// Extension Command 1
 	Write_Instruction(0x20);   // Power Control
	Write_Data(0x0b);			// VB ON ; VR,VF ON
 	Write_Instruction(0x81);   //Vop Control
	Write_Data(Contrast&0x3F);
    Write_Data((Contrast>>6)&0x07);	

	Write_Instruction(0x0C);   // Data Format Select     DO=1; LSB on top

 	Write_Instruction(0xf0);   // Display Mode
	Write_Data(0x10);		   // Monochrome Mode 

  	Write_Instruction(0xCA);   // Display Control
	Write_Data(0);
	Write_Data(95);			  //duty
	Write_Data(0x00);

	Write_Instruction(0xBC);  //ata Scan Direction
	Write_Data(0x00);		   //MY=0  

 	Write_Instruction(0xaf);	 //Display On


}


void Set_Contrast_Control_Register(unsigned int mod)
{
    Write_Instruction(0x81);
	Write_Data(mod&0x3F);
    Write_Data((mod>>6)&0x07);
	return;
}





void Set_Pos(unsigned char xs, unsigned char ys,unsigned char xe,unsigned char ye)
{ 
//	if(mode){ys+=17;ye+=17;}
//	else{ys+=9;ye+=9;}

    Write_Instruction(0x15);
	Write_Data(xs);
	Write_Data(xe);
    Write_Instruction(0x75);
	Write_Data(ys);
	Write_Data(ye);
	Write_Instruction(0x5c);
} 


				 
// ShowChar   size: 16/8 
void ShowChar(unsigned char x,unsigned char y,unsigned char chr)
{      	
	unsigned char c=0,i=0;	
		c=chr-' ';			
		if(x>192-1){x=0;if(SIZE==16)y+=2;else y+=1;}
		if(SIZE ==16)
			{
			Set_Pos(x,y,x+7,y+1);	
			for(i=0;i<8;i++)
			Write_Data(F8X16[c*16+i]);
			for(i=0;i<8;i++)
			Write_Data(F8X16[c*16+i+8]);
			}
			else {	
				Set_Pos(x,y,x+7,y);
				for(i=0;i<6;i++)
				Write_Data(F6x8[c][i]);
				
			}
}
	


//m^n
unsigned int pow(unsigned char m,unsigned char n)
{
	unsigned int result=1;	 
	while(n--)result*=m;    
	return result;
}				  

//ShowString
void ShowString(unsigned char x,unsigned char y,unsigned char *chr)
{
	unsigned char j=0;
	while (chr[j]!='\0')
	{		ShowChar(x,y,chr[j]);
			x+=8;
		if(x>184){x=0; if(SIZE==16)y+=2;else y+=1;}
			j++;
	}
}
//ShowCHinese
void ShowCHinese(unsigned char x,unsigned char y,unsigned char no)
{      			    
	unsigned char t;
	Set_Pos(x,y,x+15,y+1);	
    for(t=0;t<16;t++)
		{
				Write_Data(Hzk[32*no+t]);
			
        }			
    for(t=16;t<32;t++)
		{	
				Write_Data(Hzk[32*no+t]);
			
        }					
}
  

void DrawBMP(unsigned char x0, unsigned char y0,unsigned char x1, unsigned char y1,unsigned char BMP[])
{ 	
 unsigned int j=0;
 unsigned char x,y;
 

 Set_Pos(x0,y0,x1-1,y1-1);
	for(y=y0;y<y1;y++)
	{
    for(x=x0;x<x1;x++)
	    {      
	    	Write_Data(BMP[j++]);	    	
	    }
	}
} 





void ClearScreen(void)
{
    unsigned char i,j;

 Set_Pos(0,0,191,11);
	for(i=0;i<12;i++)
	{
        for(j=0;j<192;j++)
		{
		    Write_Data(0x00);
		}
	}
    return;
}

void Show(unsigned char d1,unsigned char d2)
{
    unsigned char i,j;

 Set_Pos(0,0,191,11);
	for(i=0;i<12;i++)
	{
        for(j=0;j<192/2;j++)
		{
		    Write_Data(d1);
			Write_Data(d2);
		}
	}
    return;
}


void Show_line_dot()
{
   Show(0x55,0xaa);
 	delay_ms(1000);
   Show(0xaa,0x55);
 	delay_ms(1000);

   Show(0x55,0x55);
 	delay_ms(1000);
   Show(0xaa,0xaa);
 	delay_ms(1000);

   Show(0xff,0x00);
 	delay_ms(1000);
   Show(0x00,0xff);
 	delay_ms(1000);

    return;
}




//ASCII
//С:6*8
/************************************6*8************************************/
const unsigned char code F6x8[][6] =		
{
0x00, 0x00, 0x00, 0x00, 0x00, 0x00,// sp
0x00, 0x00, 0x00, 0x2f, 0x00, 0x00,// !
0x00, 0x00, 0x07, 0x00, 0x07, 0x00,// "
0x00, 0x14, 0x7f, 0x14, 0x7f, 0x14,// #
0x00, 0x24, 0x2a, 0x7f, 0x2a, 0x12,// $
0x00, 0x62, 0x64, 0x08, 0x13, 0x23,// %
0x00, 0x36, 0x49, 0x55, 0x22, 0x50,// &
0x00, 0x00, 0x05, 0x03, 0x00, 0x00,// '
0x00, 0x00, 0x1c, 0x22, 0x41, 0x00,// (
0x00, 0x00, 0x41, 0x22, 0x1c, 0x00,// )
0x00, 0x14, 0x08, 0x3E, 0x08, 0x14,// *
0x00, 0x08, 0x08, 0x3E, 0x08, 0x08,// +
0x00, 0x00, 0x00, 0xA0, 0x60, 0x00,// ,
0x00, 0x08, 0x08, 0x08, 0x08, 0x08,// -
0x00, 0x00, 0x60, 0x60, 0x00, 0x00,// .
0x00, 0x20, 0x10, 0x08, 0x04, 0x02,// /
0x00, 0x3E, 0x51, 0x49, 0x45, 0x3E,// 0
0x00, 0x00, 0x42, 0x7F, 0x40, 0x00,// 1
0x00, 0x42, 0x61, 0x51, 0x49, 0x46,// 2
0x00, 0x21, 0x41, 0x45, 0x4B, 0x31,// 3
0x00, 0x18, 0x14, 0x12, 0x7F, 0x10,// 4
0x00, 0x27, 0x45, 0x45, 0x45, 0x39,// 5
0x00, 0x3C, 0x4A, 0x49, 0x49, 0x30,// 6
0x00, 0x01, 0x71, 0x09, 0x05, 0x03,// 7
0x00, 0x36, 0x49, 0x49, 0x49, 0x36,// 8
0x00, 0x06, 0x49, 0x49, 0x29, 0x1E,// 9
0x00, 0x00, 0x36, 0x36, 0x00, 0x00,// :
0x00, 0x00, 0x56, 0x36, 0x00, 0x00,// ;
0x00, 0x08, 0x14, 0x22, 0x41, 0x00,// <
0x00, 0x14, 0x14, 0x14, 0x14, 0x14,// =
0x00, 0x00, 0x41, 0x22, 0x14, 0x08,// >
0x00, 0x02, 0x01, 0x51, 0x09, 0x06,// ?
0x00, 0x32, 0x49, 0x59, 0x51, 0x3E,// @
0x00, 0x7C, 0x12, 0x11, 0x12, 0x7C,// A
0x00, 0x7F, 0x49, 0x49, 0x49, 0x36,// B
0x00, 0x3E, 0x41, 0x41, 0x41, 0x22,// C
0x00, 0x7F, 0x41, 0x41, 0x22, 0x1C,// D
0x00, 0x7F, 0x49, 0x49, 0x49, 0x41,// E
0x00, 0x7F, 0x09, 0x09, 0x09, 0x01,// F
0x00, 0x3E, 0x41, 0x49, 0x49, 0x7A,// G
0x00, 0x7F, 0x08, 0x08, 0x08, 0x7F,// H
0x00, 0x00, 0x41, 0x7F, 0x41, 0x00,// I
0x00, 0x20, 0x40, 0x41, 0x3F, 0x01,// J
0x00, 0x7F, 0x08, 0x14, 0x22, 0x41,// K
0x00, 0x7F, 0x40, 0x40, 0x40, 0x40,// L
0x00, 0x7F, 0x02, 0x0C, 0x02, 0x7F,// M
0x00, 0x7F, 0x04, 0x08, 0x10, 0x7F,// N
0x00, 0x3E, 0x41, 0x41, 0x41, 0x3E,// O
0x00, 0x7F, 0x09, 0x09, 0x09, 0x06,// P
0x00, 0x3E, 0x41, 0x51, 0x21, 0x5E,// Q
0x00, 0x7F, 0x09, 0x19, 0x29, 0x46,// R
0x00, 0x46, 0x49, 0x49, 0x49, 0x31,// S
0x00, 0x01, 0x01, 0x7F, 0x01, 0x01,// T
0x00, 0x3F, 0x40, 0x40, 0x40, 0x3F,// U
0x00, 0x1F, 0x20, 0x40, 0x20, 0x1F,// V
0x00, 0x3F, 0x40, 0x38, 0x40, 0x3F,// W
0x00, 0x63, 0x14, 0x08, 0x14, 0x63,// X
0x00, 0x07, 0x08, 0x70, 0x08, 0x07,// Y
0x00, 0x61, 0x51, 0x49, 0x45, 0x43,// Z
0x00, 0x00, 0x7F, 0x41, 0x41, 0x00,// [
0x00, 0x55, 0x2A, 0x55, 0x2A, 0x55,// 55
0x00, 0x00, 0x41, 0x41, 0x7F, 0x00,// ]
0x00, 0x04, 0x02, 0x01, 0x02, 0x04,// ^
0x00, 0x40, 0x40, 0x40, 0x40, 0x40,// _
0x00, 0x00, 0x01, 0x02, 0x04, 0x00,// '
0x00, 0x20, 0x54, 0x54, 0x54, 0x78,// a
0x00, 0x7F, 0x48, 0x44, 0x44, 0x38,// b
0x00, 0x38, 0x44, 0x44, 0x44, 0x20,// c
0x00, 0x38, 0x44, 0x44, 0x48, 0x7F,// d
0x00, 0x38, 0x54, 0x54, 0x54, 0x18,// e
0x00, 0x08, 0x7E, 0x09, 0x01, 0x02,// f
0x00, 0x18, 0xA4, 0xA4, 0xA4, 0x7C,// g
0x00, 0x7F, 0x08, 0x04, 0x04, 0x78,// h
0x00, 0x00, 0x44, 0x7D, 0x40, 0x00,// i
0x00, 0x40, 0x80, 0x84, 0x7D, 0x00,// j
0x00, 0x7F, 0x10, 0x28, 0x44, 0x00,// k
0x00, 0x00, 0x41, 0x7F, 0x40, 0x00,// l
0x00, 0x7C, 0x04, 0x18, 0x04, 0x78,// m
0x00, 0x7C, 0x08, 0x04, 0x04, 0x78,// n
0x00, 0x38, 0x44, 0x44, 0x44, 0x38,// o
0x00, 0xFC, 0x24, 0x24, 0x24, 0x18,// p
0x00, 0x18, 0x24, 0x24, 0x18, 0xFC,// q
0x00, 0x7C, 0x08, 0x04, 0x04, 0x08,// r
0x00, 0x48, 0x54, 0x54, 0x54, 0x20,// s
0x00, 0x04, 0x3F, 0x44, 0x40, 0x20,// t
0x00, 0x3C, 0x40, 0x40, 0x20, 0x7C,// u
0x00, 0x1C, 0x20, 0x40, 0x20, 0x1C,// v
0x00, 0x3C, 0x40, 0x30, 0x40, 0x3C,// w
0x00, 0x44, 0x28, 0x10, 0x28, 0x44,// x
0x00, 0x1C, 0xA0, 0xA0, 0xA0, 0x7C,// y
0x00, 0x44, 0x64, 0x54, 0x4C, 0x44,// z
0x14, 0x14, 0x14, 0x14, 0x14, 0x14,// horiz lines
};
/****************************************8*16************************************/
const unsigned char code F8X16[]=	  
{
  0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,// 0
  0x00,0x00,0x00,0xF8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x33,0x30,0x00,0x00,0x00,//! 1
  0x00,0x10,0x0C,0x06,0x10,0x0C,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,//" 2
  0x40,0xC0,0x78,0x40,0xC0,0x78,0x40,0x00,0x04,0x3F,0x04,0x04,0x3F,0x04,0x04,0x00,//# 3
  0x00,0x70,0x88,0xFC,0x08,0x30,0x00,0x00,0x00,0x18,0x20,0xFF,0x21,0x1E,0x00,0x00,//$ 4
  0xF0,0x08,0xF0,0x00,0xE0,0x18,0x00,0x00,0x00,0x21,0x1C,0x03,0x1E,0x21,0x1E,0x00,//% 5
  0x00,0xF0,0x08,0x88,0x70,0x00,0x00,0x00,0x1E,0x21,0x23,0x24,0x19,0x27,0x21,0x10,//& 6
  0x10,0x16,0x0E,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,//' 7
  0x00,0x00,0x00,0xE0,0x18,0x04,0x02,0x00,0x00,0x00,0x00,0x07,0x18,0x20,0x40,0x00,//( 8
  0x00,0x02,0x04,0x18,0xE0,0x00,0x00,0x00,0x00,0x40,0x20,0x18,0x07,0x00,0x00,0x00,//) 9
  0x40,0x40,0x80,0xF0,0x80,0x40,0x40,0x00,0x02,0x02,0x01,0x0F,0x01,0x02,0x02,0x00,//* 10
  0x00,0x00,0x00,0xF0,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x1F,0x01,0x01,0x01,0x00,//+ 11
  0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xB0,0x70,0x00,0x00,0x00,0x00,0x00,//, 12
  0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x01,0x01,//- 13
  0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x30,0x00,0x00,0x00,0x00,0x00,//. 14
  0x00,0x00,0x00,0x00,0x80,0x60,0x18,0x04,0x00,0x60,0x18,0x06,0x01,0x00,0x00,0x00,/// 15
  0x00,0xE0,0x10,0x08,0x08,0x10,0xE0,0x00,0x00,0x0F,0x10,0x20,0x20,0x10,0x0F,0x00,//0 16
  0x00,0x10,0x10,0xF8,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x3F,0x20,0x20,0x00,0x00,//1 17
  0x00,0x70,0x08,0x08,0x08,0x88,0x70,0x00,0x00,0x30,0x28,0x24,0x22,0x21,0x30,0x00,//2 18
  0x00,0x30,0x08,0x88,0x88,0x48,0x30,0x00,0x00,0x18,0x20,0x20,0x20,0x11,0x0E,0x00,//3 19
  0x00,0x00,0xC0,0x20,0x10,0xF8,0x00,0x00,0x00,0x07,0x04,0x24,0x24,0x3F,0x24,0x00,//4 20
  0x00,0xF8,0x08,0x88,0x88,0x08,0x08,0x00,0x00,0x19,0x21,0x20,0x20,0x11,0x0E,0x00,//5 21
  0x00,0xE0,0x10,0x88,0x88,0x18,0x00,0x00,0x00,0x0F,0x11,0x20,0x20,0x11,0x0E,0x00,//6 22
  0x00,0x38,0x08,0x08,0xC8,0x38,0x08,0x00,0x00,0x00,0x00,0x3F,0x00,0x00,0x00,0x00,//7 23
  0x00,0x70,0x88,0x08,0x08,0x88,0x70,0x00,0x00,0x1C,0x22,0x21,0x21,0x22,0x1C,0x00,//8 24
  0x00,0xE0,0x10,0x08,0x08,0x10,0xE0,0x00,0x00,0x00,0x31,0x22,0x22,0x11,0x0F,0x00,//9 25
  0x00,0x00,0x00,0xC0,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x30,0x00,0x00,0x00,//: 26
  0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x60,0x00,0x00,0x00,0x00,//; 27
  0x00,0x00,0x80,0x40,0x20,0x10,0x08,0x00,0x00,0x01,0x02,0x04,0x08,0x10,0x20,0x00,//< 28
  0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x00,0x04,0x04,0x04,0x04,0x04,0x04,0x04,0x00,//= 29
  0x00,0x08,0x10,0x20,0x40,0x80,0x00,0x00,0x00,0x20,0x10,0x08,0x04,0x02,0x01,0x00,//> 30
  0x00,0x70,0x48,0x08,0x08,0x08,0xF0,0x00,0x00,0x00,0x00,0x30,0x36,0x01,0x00,0x00,//? 31
  0xC0,0x30,0xC8,0x28,0xE8,0x10,0xE0,0x00,0x07,0x18,0x27,0x24,0x23,0x14,0x0B,0x00,//@ 32
  0x00,0x00,0xC0,0x38,0xE0,0x00,0x00,0x00,0x20,0x3C,0x23,0x02,0x02,0x27,0x38,0x20,//A 33
  0x08,0xF8,0x88,0x88,0x88,0x70,0x00,0x00,0x20,0x3F,0x20,0x20,0x20,0x11,0x0E,0x00,//B 34
  0xC0,0x30,0x08,0x08,0x08,0x08,0x38,0x00,0x07,0x18,0x20,0x20,0x20,0x10,0x08,0x00,//C 35
  0x08,0xF8,0x08,0x08,0x08,0x10,0xE0,0x00,0x20,0x3F,0x20,0x20,0x20,0x10,0x0F,0x00,//D 36
  0x08,0xF8,0x88,0x88,0xE8,0x08,0x10,0x00,0x20,0x3F,0x20,0x20,0x23,0x20,0x18,0x00,//E 37
  0x08,0xF8,0x88,0x88,0xE8,0x08,0x10,0x00,0x20,0x3F,0x20,0x00,0x03,0x00,0x00,0x00,//F 38
  0xC0,0x30,0x08,0x08,0x08,0x38,0x00,0x00,0x07,0x18,0x20,0x20,0x22,0x1E,0x02,0x00,//G 39
  0x08,0xF8,0x08,0x00,0x00,0x08,0xF8,0x08,0x20,0x3F,0x21,0x01,0x01,0x21,0x3F,0x20,//H 40
  0x00,0x08,0x08,0xF8,0x08,0x08,0x00,0x00,0x00,0x20,0x20,0x3F,0x20,0x20,0x00,0x00,//I 41
  0x00,0x00,0x08,0x08,0xF8,0x08,0x08,0x00,0xC0,0x80,0x80,0x80,0x7F,0x00,0x00,0x00,//J 42
  0x08,0xF8,0x88,0xC0,0x28,0x18,0x08,0x00,0x20,0x3F,0x20,0x01,0x26,0x38,0x20,0x00,//K 43
  0x08,0xF8,0x08,0x00,0x00,0x00,0x00,0x00,0x20,0x3F,0x20,0x20,0x20,0x20,0x30,0x00,//L 44
  0x08,0xF8,0xF8,0x00,0xF8,0xF8,0x08,0x00,0x20,0x3F,0x00,0x3F,0x00,0x3F,0x20,0x00,//M 45
  0x08,0xF8,0x30,0xC0,0x00,0x08,0xF8,0x08,0x20,0x3F,0x20,0x00,0x07,0x18,0x3F,0x00,//N 46
  0xE0,0x10,0x08,0x08,0x08,0x10,0xE0,0x00,0x0F,0x10,0x20,0x20,0x20,0x10,0x0F,0x00,//O 47
  0x08,0xF8,0x08,0x08,0x08,0x08,0xF0,0x00,0x20,0x3F,0x21,0x01,0x01,0x01,0x00,0x00,//P 48
  0xE0,0x10,0x08,0x08,0x08,0x10,0xE0,0x00,0x0F,0x18,0x24,0x24,0x38,0x50,0x4F,0x00,//Q 49
  0x08,0xF8,0x88,0x88,0x88,0x88,0x70,0x00,0x20,0x3F,0x20,0x00,0x03,0x0C,0x30,0x20,//R 50
  0x00,0x70,0x88,0x08,0x08,0x08,0x38,0x00,0x00,0x38,0x20,0x21,0x21,0x22,0x1C,0x00,//S 51
  0x18,0x08,0x08,0xF8,0x08,0x08,0x18,0x00,0x00,0x00,0x20,0x3F,0x20,0x00,0x00,0x00,//T 52
  0x08,0xF8,0x08,0x00,0x00,0x08,0xF8,0x08,0x00,0x1F,0x20,0x20,0x20,0x20,0x1F,0x00,//U 53
  0x08,0x78,0x88,0x00,0x00,0xC8,0x38,0x08,0x00,0x00,0x07,0x38,0x0E,0x01,0x00,0x00,//V 54
  0xF8,0x08,0x00,0xF8,0x00,0x08,0xF8,0x00,0x03,0x3C,0x07,0x00,0x07,0x3C,0x03,0x00,//W 55
  0x08,0x18,0x68,0x80,0x80,0x68,0x18,0x08,0x20,0x30,0x2C,0x03,0x03,0x2C,0x30,0x20,//X 56
  0x08,0x38,0xC8,0x00,0xC8,0x38,0x08,0x00,0x00,0x00,0x20,0x3F,0x20,0x00,0x00,0x00,//Y 57
  0x10,0x08,0x08,0x08,0xC8,0x38,0x08,0x00,0x20,0x38,0x26,0x21,0x20,0x20,0x18,0x00,//Z 58
  0x00,0x00,0x00,0xFE,0x02,0x02,0x02,0x00,0x00,0x00,0x00,0x7F,0x40,0x40,0x40,0x00,//[ 59
  0x00,0x0C,0x30,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x06,0x38,0xC0,0x00,//\ 60
  0x00,0x02,0x02,0x02,0xFE,0x00,0x00,0x00,0x00,0x40,0x40,0x40,0x7F,0x00,0x00,0x00,//] 61
  0x00,0x00,0x04,0x02,0x02,0x02,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,//^ 62
  0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,//_ 63
  0x00,0x02,0x02,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,//` 64
  0x00,0x00,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x19,0x24,0x22,0x22,0x22,0x3F,0x20,//a 65
  0x08,0xF8,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x3F,0x11,0x20,0x20,0x11,0x0E,0x00,//b 66
  0x00,0x00,0x00,0x80,0x80,0x80,0x00,0x00,0x00,0x0E,0x11,0x20,0x20,0x20,0x11,0x00,//c 67
  0x00,0x00,0x00,0x80,0x80,0x88,0xF8,0x00,0x00,0x0E,0x11,0x20,0x20,0x10,0x3F,0x20,//d 68
  0x00,0x00,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x1F,0x22,0x22,0x22,0x22,0x13,0x00,//e 69
  0x00,0x80,0x80,0xF0,0x88,0x88,0x88,0x18,0x00,0x20,0x20,0x3F,0x20,0x20,0x00,0x00,//f 70
  0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x6B,0x94,0x94,0x94,0x93,0x60,0x00,//g 71
  0x08,0xF8,0x00,0x80,0x80,0x80,0x00,0x00,0x20,0x3F,0x21,0x00,0x00,0x20,0x3F,0x20,//h 72
  0x00,0x80,0x98,0x98,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x3F,0x20,0x20,0x00,0x00,//i 73
  0x00,0x00,0x00,0x80,0x98,0x98,0x00,0x00,0x00,0xC0,0x80,0x80,0x80,0x7F,0x00,0x00,//j 74
  0x08,0xF8,0x00,0x00,0x80,0x80,0x80,0x00,0x20,0x3F,0x24,0x02,0x2D,0x30,0x20,0x00,//k 75
  0x00,0x08,0x08,0xF8,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x3F,0x20,0x20,0x00,0x00,//l 76
  0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x20,0x3F,0x20,0x00,0x3F,0x20,0x00,0x3F,//m 77
  0x80,0x80,0x00,0x80,0x80,0x80,0x00,0x00,0x20,0x3F,0x21,0x00,0x00,0x20,0x3F,0x20,//n 78
  0x00,0x00,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x1F,0x20,0x20,0x20,0x20,0x1F,0x00,//o 79
  0x80,0x80,0x00,0x80,0x80,0x00,0x00,0x00,0x80,0xFF,0xA1,0x20,0x20,0x11,0x0E,0x00,//p 80
  0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x00,0x00,0x0E,0x11,0x20,0x20,0xA0,0xFF,0x80,//q 81
  0x80,0x80,0x80,0x00,0x80,0x80,0x80,0x00,0x20,0x20,0x3F,0x21,0x20,0x00,0x01,0x00,//r 82
  0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x33,0x24,0x24,0x24,0x24,0x19,0x00,//s 83
  0x00,0x80,0x80,0xE0,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x1F,0x20,0x20,0x00,0x00,//t 84
  0x80,0x80,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x1F,0x20,0x20,0x20,0x10,0x3F,0x20,//u 85
  0x80,0x80,0x80,0x00,0x00,0x80,0x80,0x80,0x00,0x01,0x0E,0x30,0x08,0x06,0x01,0x00,//v 86
  0x80,0x80,0x00,0x80,0x00,0x80,0x80,0x80,0x0F,0x30,0x0C,0x03,0x0C,0x30,0x0F,0x00,//w 87
  0x00,0x80,0x80,0x00,0x80,0x80,0x80,0x00,0x00,0x20,0x31,0x2E,0x0E,0x31,0x20,0x00,//x 88
  0x80,0x80,0x80,0x00,0x00,0x80,0x80,0x80,0x80,0x81,0x8E,0x70,0x18,0x06,0x01,0x00,//y 89
  0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x21,0x30,0x2C,0x22,0x21,0x30,0x00,//z 90
  0x00,0x00,0x00,0x00,0x80,0x7C,0x02,0x02,0x00,0x00,0x00,0x00,0x00,0x3F,0x40,0x40,//{ 91
  0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00,//| 92
  0x00,0x02,0x02,0x7C,0x80,0x00,0x00,0x00,0x00,0x40,0x40,0x3F,0x00,0x00,0x00,0x00,//} 93
  0x00,0x06,0x01,0x01,0x02,0x02,0x04,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,//~ 94
};
unsigned char code Hzk[]={

/*--  :    --*/
/*--  12;  ¶ӦĵΪx=16x16   --*/
0x10,0x60,0x02,0x8C,0x00,0x0E,0x22,0x12,0x0A,0xC2,0x0A,0x12,0x22,0x0E,0x00,0x00,
0x04,0x04,0x7E,0x01,0x20,0x21,0x11,0x09,0x05,0xFF,0x05,0x09,0x11,0x21,0x20,0x00,

/*--  :    --*/
/*--  12;  ¶ӦĵΪx=16x16   --*/
0x20,0x20,0x20,0xFF,0x20,0x20,0x00,0xFF,0x00,0x00,0xFE,0x00,0x00,0xFF,0x00,0x00,
0x10,0x30,0x10,0x0F,0x08,0x88,0x60,0x1F,0x00,0x00,0x3F,0x00,0x00,0xFF,0x00,0x00,

/*--  :    --*/
/*--  12;  ¶ӦĵΪx=16x16   --*/
0x10,0x10,0xFF,0x10,0x10,0xF0,0x00,0x00,0xFE,0x22,0x22,0x22,0xFE,0x00,0x00,0x00,
0x80,0x60,0x1F,0x00,0x00,0x3F,0x40,0x40,0x4F,0x44,0x44,0x44,0x4F,0x40,0x78,0x00,

/*--  :    --*/
/*--  12;  ¶ӦĵΪx=16x16   --*/
0x00,0x00,0x00,0xFE,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0xFE,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xFF,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xFF,0x00,0x00,0x00,0x00,

/*--  :    --*/
/*--  12;  ¶ӦĵΪx=16x16   --*/
0x00,0x08,0x88,0x48,0x28,0x18,0x0F,0xE8,0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,
0x00,0x20,0x11,0x09,0x05,0x41,0x81,0x7F,0x01,0x01,0x05,0x09,0x11,0x20,0x00,0x00,

/*--  :    --*/
/*--  12;  ¶ӦĵΪx=16x16   --*/
0x08,0x08,0x08,0x08,0x08,0xF8,0x89,0x8E,0x88,0x88,0x88,0x88,0x08,0x08,0x08,0x00,
0x00,0x80,0x40,0x20,0x18,0x07,0x00,0x00,0x40,0x80,0x40,0x3F,0x00,0x00,0x00,0x00,

/*--  :    --*/
/*--  12;  ¶ӦĵΪx=16x16   --*/
0x24,0x24,0xA4,0xFE,0xA3,0x22,0x00,0x22,0xCC,0x00,0x00,0xFF,0x00,0x00,0x00,0x00,
0x08,0x06,0x01,0xFF,0x00,0x01,0x04,0x04,0x04,0x04,0x04,0xFF,0x02,0x02,0x02,0x00,

/*--  :    --*/
/*--  12;  ¶ӦĵΪx=16x16   --*/
0x10,0x10,0x10,0xFF,0x10,0x90,0x08,0x88,0x88,0x88,0xFF,0x88,0x88,0x88,0x08,0x00,
0x04,0x44,0x82,0x7F,0x01,0x80,0x80,0x40,0x43,0x2C,0x10,0x28,0x46,0x81,0x80,0x00,



/*--  :  ͼ  --*/
/*--  12;  ¶ӦĵΪx=16x16   --*/
0x00,0xFE,0x02,0x42,0x22,0x32,0x5E,0x92,0x52,0x32,0x12,0x02,0x02,0xFE,0x00,0x00,
0x00,0xFF,0x42,0x42,0x42,0x51,0x55,0x64,0x69,0x41,0x42,0x42,0x42,0xFF,0x00,0x00,

/*--  :    --*/
/*--  12;  ¶ӦĵΪx=16x16   --*/
0x80,0x82,0x82,0xFE,0x82,0x82,0xFE,0x82,0x82,0x80,0x20,0x10,0x08,0x86,0x60,0x00,
0x80,0x40,0x30,0x0F,0x00,0x00,0xFF,0x00,0x00,0x80,0x84,0x42,0x21,0x10,0x0C,0x00,

/*--  :    --*/
/*--  12;  ¶ӦĵΪx=16x16   --*/
0x00,0x00,0x00,0xFE,0x92,0x92,0x92,0x92,0x92,0x92,0x92,0xFE,0x00,0x00,0x00,0x00,
0x40,0x42,0x44,0x58,0x40,0x7F,0x40,0x40,0x40,0x7F,0x40,0x50,0x48,0x46,0x40,0x00,

/*--  :  ʾ  --*/
/*--  12;  ¶ӦĵΪx=16x16   --*/
0x40,0x40,0x42,0x42,0x42,0x42,0x42,0xC2,0x42,0x42,0x42,0x42,0x42,0x40,0x40,0x00,
0x20,0x10,0x08,0x06,0x00,0x40,0x80,0x7F,0x00,0x00,0x00,0x02,0x04,0x08,0x30,0x00,

/*--  :  ģ  --*/
/*--  12;  ¶ӦĵΪx=16x16   --*/
0x10,0x10,0xD0,0xFF,0x90,0x14,0xE4,0xAF,0xA4,0xA4,0xA4,0xAF,0xE4,0x04,0x00,0x00,
0x04,0x03,0x00,0xFF,0x00,0x89,0x4B,0x2A,0x1A,0x0E,0x1A,0x2A,0x4B,0x88,0x80,0x00,

/*--  :    --*/
/*--  12;  ¶ӦĵΪx=16x16   --*/
0x20,0x30,0xAC,0x63,0x30,0x00,0x00,0xFE,0x22,0x22,0x22,0x22,0xFE,0x00,0x00,0x00,
0x22,0x67,0x22,0x12,0x12,0x40,0x40,0x7F,0x42,0x42,0x42,0x42,0x7F,0x40,0x40,0x00,

/*--  :    --*/
/*--  12;  ¶ӦĵΪx=16x16   --*/
0x10,0x60,0x02,0x8C,0x00,0xFE,0x02,0xF2,0x02,0xFE,0x00,0xF8,0x00,0xFF,0x00,0x00,
0x04,0x04,0x7E,0x01,0x80,0x47,0x30,0x0F,0x10,0x27,0x00,0x47,0x80,0x7F,0x00,0x00,

/*--  :    --*/
/*--  12;  ¶ӦĵΪx=16x16   --*/
0x40,0x40,0x42,0xCC,0x00,0x90,0x90,0x90,0x90,0x90,0xFF,0x10,0x11,0x16,0x10,0x00,
0x00,0x00,0x00,0x3F,0x10,0x28,0x60,0x3F,0x10,0x10,0x01,0x0E,0x30,0x40,0xF0,0x00,

};



unsigned char code pic1[]=
{
/* 0X32,0X01,0X00,0XC0,0X00,0X60, */
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X80,0XC0,0XE0,0XF0,0XF8,0XFC,0XFC,
0XFE,0XFE,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0XFF,0XFF,
0X10,0X08,0XF8,0XF0,0X00,0X00,0XF8,0XF8,0X00,0X00,0XF8,0XF8,0X00,0X18,0XF8,0XE0,
0X00,0XE0,0XF8,0X18,0X00,0XF0,0XF8,0X08,0X10,0XFF,0XFF,0X00,0X00,0XFB,0XFB,0X00,
0X30,0X78,0X68,0XC8,0XD8,0X90,0X00,0XF8,0XF8,0X10,0X08,0XF8,0XF0,0X00,0X00,0XFF,
0XFF,0X00,0X00,0X90,0XC8,0X68,0X28,0XF8,0XF0,0X00,0X18,0XF8,0XE0,0X00,0XE0,0XF8,
0X18,0X00,0X00,0X00,0X00,0X00,0XF0,0XF8,0X08,0X08,0X18,0X10,0X00,0XF0,0XF8,0X08,
0X08,0XF8,0XF0,0X00,0X00,0XF8,0XF8,0X10,0X08,0XF8,0XF8,0X10,0X08,0XF8,0XF0,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFE,0XFE,0XFC,0XFE,0XFC,0XFC,0XF8,0XF0,0XF0,0XE0,0XC0,0XC0,0XE0,0XE0,
0XE0,0XF0,0XF0,0XF0,0XF0,0XF0,0XE0,0XE0,0XC0,0X80,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X80,0XE0,0XF8,0XFC,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XE0,0XE3,0XE3,
0XE1,0XE2,0XE3,0XE1,0XE0,0XE0,0XE1,0XE3,0XE2,0XE1,0XE3,0XE3,0XE0,0XF0,0XF0,0XFF,
0XFF,0XE7,0XE0,0XE0,0XE0,0XE1,0XE3,0XE2,0XE1,0XE3,0XE3,0XE0,0XE0,0XE3,0XE3,0XE0,
0XE1,0XE3,0XC2,0X02,0X03,0X01,0X00,0X1F,0X1F,0X01,0X02,0X03,0X01,0X00,0X00,0X03,
0X03,0X00,0X00,0X01,0X03,0X02,0X02,0X03,0X03,0X00,0X10,0X10,0X1F,0X1F,0X07,0XE0,
0XE0,0XE0,0XE3,0XE3,0XE0,0XE0,0XE1,0XE3,0XE2,0XE2,0XE3,0XE1,0XE0,0XE1,0XE3,0XE2,
0XE2,0XE3,0XE1,0XE0,0XE0,0XE3,0XE3,0XE0,0XE0,0XE3,0XE3,0XE0,0XE0,0XE3,0XE3,0XE0,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0XFC,0XF8,0XF0,0XE0,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0XE0,0XF8,0XFE,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0XF0,0XE0,0XC0,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X03,
0X07,0XEF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X7F,0XFF,0XFF,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X80,0XE0,
0XFE,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X1F,
0X07,0X00,0X03,0X00,0X03,0X00,0X01,0X00,0X01,0X00,0X01,0X00,0X01,0X00,0X01,0X00,
0X01,0X00,0X01,0X00,0X01,0X01,0X03,0X07,0X0F,0X2F,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XBF,0X7C,0XF8,0XE0,0X80,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X80,0XE0,0XFC,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0X1F,0X07,0X07,0X03,0X03,0X03,0X03,0X03,0X03,0X07,0X07,0X2F,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0XEB,0X7F,0XFD,0XFF,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XA0,0XF8,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X7F,0X3F,0X1F,0X0F,0X07,0X01,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X02,0X0B,0X3F,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X01,0X0F,0XFF,0XFE,0XF0,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XA0,0XF8,0X3F,0X07,0XF5,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0X07,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X0B,0XBF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XBF,0XFF,0XFF,0XFF,0X47,0XBF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X5D,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XE0,0XFC,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X7F,0X7F,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0X3F,0X07,0X03,0X01,0X08,0X0C,0X0C,0X8C,0X8C,0X8C,0X8C,0X8C,
0X8C,0X9C,0X1C,0X98,0X18,0X30,0X30,0X70,0X20,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X60,0X30,0X30,0X98,0X98,0X9C,0XCC,0X8E,0XCC,0XC6,0X86,0XC6,0X06,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X7F,0XFF,0XFF,0X5F,0X00,0X00,0X00,0XFF,0XFF,0X7F,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,0X0F,0X18,0X00,0X00,
0X1F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X7F,0X30,0X6F,0X7F,0XFF,0X7F,0XFF,0XC1,
0XD7,0X80,0X80,0X00,0X00,0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X80,0X80,0XBF,0XBF,0XFF,0XDF,0X8F,0XC1,0XD4,0XFF,0X87,0XDA,0X85,0X80,0X8F,0XBF,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X7F,0XFF,0XFF,0XFE,0XFD,0XFF,0XFF,0XFF,0XFC,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XC0,0XF8,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XE3,0XF9,0XFE,0XFF,0X5F,0X17,0X21,0X00,0X00,0X00,0X00,0XFF,
0XFF,0X7F,0X07,0X01,0X00,0X00,0X00,0X00,0X00,0X02,0X0F,0X1F,0X3F,0X3D,0X3F,0X3F,
0X3F,0X2F,0X23,0X03,0X06,0X17,0X14,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X1A,0X0E,0X1F,0X3D,0X3F,0X3F,0X3F,0X37,0X38,0X15,0X27,0X00,0X8F,
0XAF,0XFF,0XFF,0XFF,0X3F,0X17,0X00,0XFF,0X7F,0X00,0X00,0X00,0X3D,0X0F,0X01,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X30,0XCF,0X17,0X7F,0XFF,0X44,0X01,0X61,0XF9,0X3C,0X7C,0XFC,0XFC,0XF8,0XD8,0X98,
0XF0,0XF1,0XC3,0X03,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X02,0X03,
0X03,0XA9,0XC1,0XF1,0XE1,0XF1,0XF1,0XF8,0XF1,0XB8,0XB1,0XF0,0XF0,0XE0,0XC1,0XA1,
0X01,0XFF,0X0F,0XBF,0X5F,0X03,0X01,0X7F,0XFF,0XFF,0XFF,0XFF,0X7F,0X8F,0X6F,0X47,
0X27,0X23,0XC7,0X07,0X1F,0XFF,0X03,0X00,0X00,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0X00,0X00,0X00,0X00,0XC0,0XF8,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF0,0XE0,0XC1,0X82,0XC2,0X80,0XFA,0XFF,
0XFF,0X01,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0XC0,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0XFB,0X7F,0X07,0X01,0X00,0X08,0X07,0X01,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X06,0X38,0XA3,0XFF,0X00,0X00,0X00,0X08,0X07,0X0F,0X07,0X0F,0X07,0X07,
0X03,0X01,0X01,0X01,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X02,0X01,0X08,0X03,0X0F,0X0F,0X0F,0X1F,0X0F,0X0F,0X0F,0X0C,0X03,0X01,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X02,0X7F,0XFF,0XFF,0X03,0XF0,0X9F,0X61,0X1A,
0X05,0X00,0X87,0X80,0X60,0X1F,0X00,0X00,0X00,0X00,0X3F,0XFF,0XFF,0XFF,0XFF,0X1F,
0X00,0X00,0X00,0XFE,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XC0,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X10,0X00,0X00,0X20,0X00,
0X30,0X08,0X17,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XC0,0XF8,0XFE,
0X07,0X01,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0XC0,0X1C,0X1E,0X07,0XFC,0X40,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X20,0XC0,0X00,0X00,0X00,0X00,0X80,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X2A,0X8F,0XF0,0XF0,0XF0,0XF0,0X78,0X0C,
0X04,0X03,0X01,0X00,0X00,0X00,0X00,0X00,0X00,0X80,0X80,0XCF,0XEF,0XF3,0XFC,0XFF,
0X00,0X00,0XFE,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X7F,
0X7F,0XFC,0X43,0X04,0X08,0X10,0X30,0X40,0X80,0X80,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X08,0X0C,0X0C,0X08,0X1C,0X2C,0X5C,0X2C,0X38,0X2C,0X58,0X2C,
0X1E,0X0C,0X16,0X06,0X00,0X00,0X00,0X80,0X40,0X20,0X18,0X06,0X00,0X07,0XFF,0XFF,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X40,0X00,
0X28,0X07,0X00,0X00,0X00,0X80,0XF0,0XFF,0X78,0XE0,0XC0,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X60,0XE0,0X60,0XE1,0X40,0XE1,0X40,0X41,0XC0,0XC0,0XC0,0XC0,0XC0,
0X80,0X40,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0XC0,0X20,0X18,0X9E,0XFF,0XFF,0X7F,0X0F,0X01,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X04,0X03,0X00,0X01,0XFF,0XAF,0XFF,0XFF,0XFF,
0X00,0X00,0X3F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XA7,0X5E,0X3B,0XF5,
0XC0,0X0B,0X2F,0XD0,0X00,0X00,0X00,0X00,0X00,0X00,0X03,0X02,0X02,0X0C,0X08,0X08,
0X30,0X30,0X60,0X80,0XC0,0X80,0X80,0X00,0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X80,
0XC0,0XA0,0XB0,0X18,0X0C,0X06,0X03,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,0X07,
0X0F,0X70,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X38,0X1C,0X1E,0X04,0X05,0X00,0X00,
0X00,0X00,0X80,0XF0,0XFC,0X3F,0X07,0XA8,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0XF8,0XF0,
0X20,0XC0,0X00,0X00,0X00,0X03,0X05,0X07,0X0D,0X06,0X05,0X04,0X04,0X00,0X01,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X80,0X40,0X20,0X00,0X10,
0X00,0X04,0X02,0X01,0X01,0X00,0X00,0X00,0XFF,0X5F,0X1B,0XFC,0XF0,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X80,0XFC,0XFF,0X06,0X00,0XFF,0XFF,
0X00,0X00,0X00,0X07,0X3F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XB4,0X4B,0XB4,0X48,
0X30,0XC3,0X04,0X04,0X08,0X08,0X00,0X10,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X02,0X01,0X02,0X09,0X02,0X09,0X07,0X01,0X9B,0X01,0X6B,
0X95,0X00,0X00,0X01,0X02,0X0C,0X08,0X30,0XE0,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X80,0XE0,0XF8,
0XFE,0X7F,0X1F,0X07,0XC1,0XF0,0XFC,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X07,
0XE0,0XF0,0X79,0X1F,0X1E,0XBC,0XD0,0X10,0X30,0X20,0X60,0X20,0X40,0X60,0X20,0X20,
0X10,0X10,0X18,0X08,0X08,0X04,0X06,0X04,0X01,0X01,0X01,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X80,0X80,0XC0,0XE0,0X70,0X38,0X3F,0X1C,0X0F,0X03,0X77,0X01,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X80,0XC0,0XF8,0X5E,0X0F,0X01,0X00,0X00,0XC0,0XFF,0XFF,
};

unsigned char code pic2[]=
{
/* 0X32,0X01,0X00,0XC0,0X00,0X60, */
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X08,0XF8,0XFC,0X8C,0XC4,
0XC6,0XC6,0X46,0XC4,0XCC,0XC6,0XC3,0XE1,0XE3,0XF3,0XF3,0XF7,0XFF,0XDC,0X90,0XF0,
0XFC,0XFE,0XFE,0XFE,0XFE,0XFC,0XFC,0XFC,0XFC,0XFC,0XFC,0XC0,0X80,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0XC0,0X70,0XFE,0XBF,0X7F,0X7F,0XF8,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0XE0,0XF8,0XFC,0XFE,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0XFC,0XFC,0XD6,
0X82,0X83,0X03,0X03,0X01,0X01,0X03,0X03,0X03,0X01,0X01,0X87,0XFF,0X7B,0X70,0X60,
0XC0,0XE0,0XE0,0XF0,0XF0,0XF0,0XF0,0XE0,0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X80,0XFE,
0X7F,0X7F,0XFF,0XFF,0XFF,0XEF,0XFF,0X7F,0XF0,0XF0,0XF0,0XF0,0XF0,0XB1,0XB1,0XA1,
0XB1,0X73,0XFE,0XA4,0X40,0XC0,0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X70,0XFC,0XFE,0XFF,0XFF,0XFF,0XFF,0XFF,0X7E,
0X38,0X24,0X66,0X42,0XC3,0XC2,0XC2,0XC3,0XC5,0XC7,0XCB,0XF8,0XD0,0X00,0X00,0X00,
0X00,0XF8,0XF8,0XFE,0XFE,0XFE,0XFE,0XFE,0XFC,0X7C,0X1E,0X07,0X8F,0XCF,0XEF,0XEF,
0XFF,0XF7,0X77,0X63,0XE1,0XC0,0X00,0X01,0XE1,0XFB,0X3B,0X1F,0X1F,0X3D,0X3C,0XFC,
0XF9,0XFB,0XF7,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X3F,0X0E,0X04,0X00,
0X00,0X0C,0X0C,0X0E,0X0F,0X0F,0X0F,0X0D,0X09,0X0F,0X0E,0X1F,0X7E,0XE0,0X00,0X00,
0X00,0X00,0X00,0X00,0XC3,0X67,0X1F,0X07,0X03,0X9F,0X9F,0XFF,0XFF,0XFE,0XFE,0X7E,
0X3D,0X3B,0X1F,0X06,0X06,0X1E,0X3F,0X7F,0X7F,0X7F,0XFD,0XFD,0X7D,0X7F,0X7F,0X3E,
0X01,0X07,0X0F,0XFF,0X3F,0X3F,0X3F,0X1F,0X07,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X80,0XC0,0X60,0X30,0X10,0XF8,0XFC,0X0F,0X87,0XE6,
0XF6,0X36,0X0E,0X00,0X00,0X00,0X80,0XE0,0XF1,0X13,0X1F,0X1F,0XFF,0XFF,0XFF,0XE7,
0X07,0X03,0X01,0X01,0X00,0X00,0X01,0X1F,0XFE,0XFF,0XFF,0XFF,0XFF,0XFE,0XFC,0X00,
0X00,0X00,0X00,0XC0,0X60,0X18,0X0C,0X06,0X03,0X01,0X01,0X01,0X01,0X01,0X00,0X00,
0X00,0X00,0X00,0X00,0X07,0X0F,0X1F,0X1F,0X3F,0X9F,0XDF,0XDF,0XCC,0X87,0X78,0XC0,
0X00,0X01,0X01,0X03,0X07,0X07,0X07,0XFF,0XFF,0X00,0X00,0XFE,0XFF,0XFF,0XFF,0XC3,
0X80,0X9C,0X84,0XC4,0X6C,0X03,0X80,0XC0,0XC3,0XC0,0X06,0X01,0X03,0X32,0X30,0X38,
0X3F,0X3F,0X3F,0X1F,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XF0,0X98,0X0F,0X1F,0X7A,
0XF2,0XF2,0XFE,0X0F,0XFB,0XFC,0XFE,0XFF,0XFF,0XFF,0XB7,0X9B,0XCB,0X3F,0X3F,0X0F,
0X00,0X00,0X00,0X00,0X78,0X3E,0X3E,0X6F,0X0F,0XFF,0XFE,0XFE,0XFC,0XFC,0XF8,0X40,
0X00,0X00,0X00,0XFF,0XDF,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X80,
0X00,0X00,0X00,0X00,0X7C,0XFF,0X01,0X00,0X18,0X30,0X40,0XC0,0XC1,0X41,0X66,0XC6,
0X06,0X04,0X00,0X00,0X00,0X0F,0X1F,0X33,0X31,0X70,0X78,0X7C,0X3F,0X3F,0X1F,0X0F,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XF8,0X3F,0X07,0X07,0X07,0X03,0X03,0X00,0X80,
0XF0,0X1C,0X03,0X01,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X1C,0XFF,0XFF,0XC3,0X81,0X79,0X7B,0X02,0X07,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XFF,0XFF,0X00,0X00,0X01,0X03,0X03,0X03,0X03,
0X03,0X03,0X01,0X00,0X00,0X0C,0X0C,0X0C,0X07,0X06,0X04,0X04,0X07,0X03,0X00,0X00,
0X00,0X00,0X00,0X80,0XE0,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X03,0X07,0X06,0X04,
0X0E,0X1F,0XFF,0XD8,0X30,0X61,0XC3,0X83,0X03,0X03,0X23,0X61,0X63,0X67,0X63,0X60,
0X20,0X00,0X00,0X00,0X00,0X03,0X03,0X07,0X07,0X0F,0X0F,0X0F,0X07,0X07,0X83,0X80,
0XC0,0X70,0X38,0X1F,0X07,0X00,0X00,0X00,0X00,0X00,0X70,0XF8,0XFC,0XFE,0XFF,0XFF,
0XBF,0XBE,0X78,0XF8,0XF8,0XF1,0XF7,0XEC,0XF8,0XE0,0XC0,0XC0,0X80,0X80,0X00,0X01,
0X03,0X06,0X0C,0X08,0X18,0X10,0X10,0X10,0X10,0X10,0X10,0X18,0X08,0X0C,0X04,0X00,
0X00,0X00,0X00,0X80,0XC0,0X70,0X1F,0X03,0X00,0X00,0X00,0X00,0X00,0X00,0X0F,0X1F,
0X71,0XC0,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,0X01,0X00,0X40,0XB0,0XD8,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X03,0X07,0X0E,0X0C,0X08,0X18,0X18,0X10,
0X10,0XB0,0XF0,0XF0,0XF0,0XF0,0XF0,0X30,0X30,0X10,0X10,0X00,0X00,0X08,0X08,0X04,
0X06,0X02,0X03,0X07,0X07,0X0F,0X0F,0X3F,0XFF,0X1F,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X03,0X0F,0X3C,0XF0,0XC1,0XF9,0X3F,0X1E,0X0E,0X04,0X04,0X04,0X0C,
0X0C,0X0C,0X08,0X08,0X08,0X0C,0XFC,0XFC,0X1C,0X0C,0X1C,0X3E,0X7E,0XFF,0XF9,0X01,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XC0,0XC0,0XF0,0XFC,0XFF,0XDF,0XB7,0XA1,0XB0,
0XDF,0XE7,0XF8,0X7F,0X3F,0XBF,0X7F,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,
0XFE,0XFE,0XFC,0XFC,0XFC,0XFC,0XFC,0XFC,0XF8,0XFC,0XFC,0XFC,0XFC,0X04,0X06,0X06,
0X02,0X03,0X03,0X01,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X03,0X82,0XC4,0XAC,0XF8,0X38,0XF8,0XF0,0XF8,0XFC,0XFC,0XFC,0XFC,
0X38,0X20,0X00,0X00,0X30,0X10,0X30,0XF8,0X08,0X0C,0X04,0X06,0X03,0X01,0X01,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X3C,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X18,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X07,0XFF,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0XFE,0X0F,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X01,0X01,0X03,0X0E,0XF8,0X90,0X80,0X00,0X03,0X8E,
0XFC,0X10,0X00,0X00,0X00,0X00,0X00,0X01,0X01,0X03,0X07,0X0F,0X0F,0X1F,0X1F,0X1F,
0X3F,0X3F,0XF8,0XF2,0XE2,0XE6,0XEC,0XF0,0XFF,0XFF,0XFF,0XFF,0X7F,0X1F,0X07,0X07,
0X0F,0X1F,0X3F,0X7F,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X1F,0X01,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0XF8,0XFF,0XFF,0XFF,0XFE,0XFF,0XFF,0XFF,0XFF,0X3F,0X0F,0X03,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,0XFF,0XFE,0XFC,0XFC,0XFC,0X78,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X01,0XFB,0X7F,0X03,0X01,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XFF,0X1F,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0XFE,0XFE,0X20,0X10,0XF0,0XE0,0X00,0X00,0XF0,0XF0,0X00,
0X00,0XF0,0XF0,0X00,0X30,0XF0,0XC1,0X00,0XC0,0XF0,0X30,0X00,0XE0,0XF0,0X10,0X20,
0XFE,0XFE,0X00,0X00,0XF6,0XF6,0X00,0X60,0XF0,0XD0,0X90,0XB1,0X21,0X01,0XF1,0XF1,
0X20,0X10,0XF0,0XE0,0X00,0X00,0XFE,0XFE,0X00,0X00,0X20,0X90,0XD0,0X50,0XF0,0XE0,
0X00,0X30,0XF1,0XC1,0X00,0XC0,0XF0,0X31,0X01,0X01,0X01,0X00,0X00,0XE0,0XF0,0X10,
0X10,0X30,0X20,0X00,0XE0,0XF0,0X11,0X11,0XF1,0XE1,0X00,0X00,0XF0,0XF0,0X20,0X10,
0XF0,0XF0,0X20,0X10,0XF0,0XE0,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X03,0X07,0XCF,0X7F,0X1F,0X27,0XE7,0X87,0X01,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X38,0X7F,0XC1,0X01,0X01,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X0F,0X98,0X90,0X80,0X80,0X80,0X00,0X00,0X00,0X19,0X0F,0X02,0X02,0X1E,
0X12,0X00,0X00,0X00,0X00,0X00,0X10,0X10,0X1E,0X13,0X10,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X07,0X87,0X82,0X84,0X87,0X03,0X00,0X80,0X03,0X07,0X04,
0X02,0X07,0X87,0X80,0XA0,0XA1,0XBF,0X3E,0X0F,0X01,0X00,0X00,0X03,0X07,0X04,0X02,
0X07,0X07,0X00,0X00,0X07,0X07,0X00,0X02,0X06,0X04,0X05,0X07,0X03,0X00,0X3F,0XBF,
0XC2,0XC4,0XC7,0XC3,0X40,0X40,0X07,0X47,0X40,0XC0,0XC3,0XC7,0XC4,0XC4,0XC7,0XC7,
0X80,0X20,0X21,0X3F,0X3E,0X0F,0X01,0X00,0X00,0X06,0X06,0X00,0X00,0X03,0X07,0X04,
0X04,0X06,0X02,0X00,0X03,0X07,0X04,0X04,0X07,0X03,0X00,0X00,0X07,0X07,0X00,0X00,
0X07,0X07,0X00,0X80,0X87,0X87,0X80,0X80,0X80,0X80,0X80,0X80,0XC0,0XC0,0XC0,0X80,
0X00,0X00,0X00,0X00,0X00,0X93,0XC6,0XCC,0X98,0X90,0X11,0X13,0X16,0X1E,0X0C,0X0C,
0X1C,0X10,0X00,0X00,0X00,0X10,0XD0,0XF8,0X8C,0X03,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X80,0XC0,0X60,0X70,0X20,0X60,0XE0,0XC0,0X80,
0X00,0X3E,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0XFE,0XF8,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X80,0X68,0XFC,0XE5,0XE3,0XE2,0XE1,0XE1,0XE1,0XE1,0X21,0X33,0X12,
0X1C,0X3F,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0X38,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X80,0X80,0X80,0X80,0X00,0X80,0XC0,0X60,0X20,0XD2,0XFF,0XB9,
0XD8,0XD0,0XD8,0XD8,0XF8,0XF8,0XF8,0XF8,0XF8,0X3F,0X7F,0X77,0X7F,0X7F,0X7F,0X3F,
0X3F,0X7F,0XC0,0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XC0,0XF0,0XF8,0XF8,0XF8,0XF8,0XF0,0XF0,
0XE0,0X30,0XB8,0XBD,0XFF,0XC3,0X80,0X80,0X81,0X81,0X81,0X00,0X00,0X01,0X81,0XC1,
0XC1,0X6B,0X7E,0X7E,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0XFC,0X70,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0XFC,0X3F,0XBF,0XDF,0XFF,0XB8,0XE0,0X80,0X00,0X00,0X00,
0XF0,0XFC,0XFE,0XFC,0XFC,0XC7,0X83,0X01,0XE0,0XF0,0XD8,0XEC,0XF6,0XFA,0XFF,0XFF,
0XFF,0XFF,0XFF,0XC0,0XE0,0XE0,0XC1,0XC1,0X81,0X03,0X07,0X0C,0X18,0X30,0X60,0XC0,
0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0XE0,0X3C,0XC3,0XE6,0XEF,0XEF,0XCF,0X9F,0X0F,0X0F,0X07,0X03,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,0X03,0X06,0X0C,0X30,0XE0,0X80,0X00,
0X00,0X00,0X7E,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X0F,0X00,0X00,0X00,0X00,0X00,0X01,
0X03,0XF3,0XFF,0XFF,0XFF,0X0F,0X0F,0X09,0XF8,0XF0,0XC0,0X80,0X00,0X00,0X07,0X1B,
0X7B,0X73,0X43,0X87,0XFE,0X7C,0X08,0X18,0X30,0X60,0XC0,0X80,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X03,0X0F,0X1F,0X1F,0X9F,0XFF,0X07,0X03,
0X00,0X1F,0X3F,0X3F,0X3E,0X7E,0X7E,0XBF,0XBF,0XBF,0X1F,0X0F,0X03,0X03,0X0F,0X1D,
0X1E,0XBF,0XFF,0XFF,0XFF,0XFF,0XCF,0XCF,0X81,0X83,0X0F,0X33,0XE1,0X80,0X00,0X00,
0X00,0X00,0X80,0XF0,0X3F,0X0F,0X07,0X07,0X04,0X06,0X07,0X07,0X07,0X07,0X06,0X06,
0X01,0X03,0X1F,0X3F,0X7B,0XFF,0XFF,0XFF,0XCF,0X81,0X02,0X03,0X03,0X03,0X03,0X03,
0X3F,0XEF,0XE7,0XC3,0X03,0X07,0X0F,0XFF,0XFF,0XFF,0XFE,0XFC,0X00,0X00,0X00,0X00,
0X03,0X06,0X0C,0X38,0XE0,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XE0,0X70,
0X1E,0X03,0X01,0X3D,0X3C,0XC0,0XE1,0X7F,0X7F,0X0E,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,0X0E,
0XF8,0XC0,0X80,0X01,0X01,0X03,0X03,0X03,0X1F,0XFC,0X80,0X00,0X00,0X00,0X00,0X00,
0X00,0X07,0X0F,0X1F,0X1F,0X3E,0X3C,0X38,0X18,0X19,0X0F,0X07,0X00,0X00,0X00,0X02,
0X83,0XE3,0X33,0X20,0X60,0X60,0X20,0X18,0X0C,0X00,0X80,0XFF,0X3E,0X00,0X00,0X00,
0X80,0XC0,0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XEF,0XFF,0X00,0X00,
0X00,0X20,0XFC,0XFE,0XFE,0XFF,0XFF,0XFF,0X87,0XB7,0X9F,0X9F,0X3C,0X00,0X00,0X00,
0X00,0X07,0X9F,0X9F,0XE5,0XCD,0XDB,0XFF,0XFF,0XFF,0XFF,0XFE,0X7D,0X07,0XFF,0XF9,
0X79,0X3D,0X0F,0X87,0XCC,0X78,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X01,0X1F,0XFF,0XF1,0XE1,0XC7,0XDE,0XDC,0X00,0X60,0X70,
0X00,0X00,0X01,0X01,0X00,0X06,0X86,0XC7,0X63,0X1B,0X0D,0X04,0X00,0X00,0X00,0X00,
0XC0,0XE0,0XF8,0XEF,0XE3,0XC0,0XC0,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X03,0X1E,
0X30,0X6C,0XD8,0XA0,0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X80,0X00,0X60,
0X38,0X0F,0X07,0X00,0X00,0X00,0X00,0X00,0X00,0X01,0X0F,0X38,0X60,0XC0,0X80,0X80,
0X00,0X00,0X02,0X06,0X04,0X0C,0X08,0X08,0X08,0X08,0X08,0X08,0X0C,0X04,0X06,0X03,
0X01,0X00,0X80,0XC0,0XC0,0XE0,0XE0,0XF0,0XFC,0XF6,0XFB,0XF8,0XFC,0XFC,0X3C,0XDF,
0XDF,0X7F,0XFF,0XFF,0XFE,0XFC,0X38,0X00,0X00,0X00,0X00,0X00,0X03,0X0F,0X1C,0X38,
0X60,0XC0,0XC1,0X83,0X03,0X07,0X07,0X07,0X03,0X03,0X01,0X01,0X00,0X00,0X00,0X00,
0X10,0X30,0X31,0X33,0X31,0X30,0X11,0X81,0X81,0XC1,0X61,0X30,0X98,0XEC,0X7F,0X0F,
0X07,0X02,0X03,0X03,0X01,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,

};


unsigned char code pic3[]=
{/* 0X32,0X01,0X00,0XC0,0X00,0X60, */
0XFF,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0XE1,0XE1,0X01,0XFD,0XFD,0X01,0X01,0X01,
0X01,0X01,0X41,0X61,0X31,0X31,0X31,0X31,0XF1,0XE1,0X01,0X01,0X81,0XE1,0X61,0X31,
0X31,0X31,0X31,0X71,0XE1,0X41,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,
0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,
0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,
0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,
0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,
0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,
0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,
0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0X01,0XF9,0XF9,0X19,
0X19,0X99,0X99,0X19,0X19,0X99,0X99,0X99,0X99,0X19,0X19,0X99,0X99,0X99,0X99,0X19,
0X19,0X99,0X99,0X99,0X99,0X19,0X19,0XF9,0XF9,0X01,0X01,0X01,0X01,0X01,0X01,0XFF,
0XFF,0X00,0XF8,0XF8,0X00,0XFF,0XFF,0X00,0XFF,0XFF,0X00,0XFF,0XFF,0X00,0X00,0X00,
0X00,0X00,0X30,0X70,0XE0,0XC3,0XC3,0XE7,0X7F,0X3C,0X00,0X00,0X1F,0X7F,0X60,0XC0,
0XC0,0XCC,0XCC,0XEC,0X7C,0X3C,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X3F,0X3F,0X33,0XF3,0XF3,0X00,
0X00,0X7F,0X7F,0X00,0X00,0X7F,0X7F,0X7F,0X7F,0X00,0X00,0X7F,0X7F,0X7F,0X7F,0X00,
0X00,0X7F,0X7F,0X7F,0X7F,0X00,0X00,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,0X00,0XFF,
0XFF,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X07,0X07,0X06,
0X06,0X06,0X06,0X06,0X06,0X06,0X06,0X06,0X06,0X06,0X06,0X06,0X06,0X06,0X06,0X06,
0X06,0X06,0X06,0X06,0X06,0X06,0X06,0X07,0X07,0X00,0X00,0X00,0X00,0X00,0X00,0XFF,
0XFF,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X80,0XC0,
0XF0,0XF8,0XFE,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XC0,0XE0,0XF0,0XF8,0XFC,
0XFC,0XFE,0XFE,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0XFE,0XFE,0XFC,
0XFC,0XF8,0XF0,0XE0,0XC0,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0XC0,0XF0,0XF8,0XFC,0XFC,0XFE,0XFE,0XFE,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0XFE,0XFC,0XFC,0XF8,0XF0,0XE0,0XC0,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0XC0,0XE0,0XF8,0XFC,0XFE,0XFE,0XFE,0XFE,0XFE,0XFE,0XFE,0XFE,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XFF,
0XFF,0X00,0X00,0X00,0X00,0X00,0XF0,0XF8,0XF8,0XFC,0XFC,0XFE,0XFF,0XFF,0XFF,0X7F,
0X3F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X38,0X3F,0X3F,0X3F,0X7F,0X7F,0X7F,
0X7F,0X7F,0X0F,0X03,0X01,0X00,0X00,0X00,0X00,0X00,0X01,0X01,0X07,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0XF0,0XF0,0XF0,0XF0,0XF0,0XF0,0XF0,0XF0,0XF0,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X1C,0X1F,0X1F,0X1F,0X1F,0X1F,0X3F,0X3F,0X3F,0X0F,0X03,0X01,
0X00,0X00,0X00,0X00,0X01,0X83,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X7E,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X80,0XC0,
0XF0,0XF8,0XFE,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XFF,
0XFF,0X00,0X00,0X00,0X00,0X00,0X1F,0X0F,0X0F,0X07,0X07,0X03,0X01,0X01,0X00,0X00,
0X00,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X80,0XC0,0XE0,0XF0,0XF8,0XFE,0XFF,0XFF,0XFF,
0XFF,0XFF,0X7F,0X1F,0X07,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X1F,0X1F,0X1F,0X1F,0X1F,0X1F,0X1F,0X1F,0X1F,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XE0,
0XFC,0XFC,0XFC,0XFE,0XFE,0XFF,0XFF,0XFF,0XFF,0XDF,0XCF,0X87,0X83,0X01,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XC0,0XE0,0XF0,0XFC,0XFE,0XFF,0XFF,
0XFF,0X7F,0X1F,0X0F,0X03,0X01,0X00,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XFF,
0XFF,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X80,
0XC0,0XE0,0XF0,0XF8,0XFC,0XFE,0XFF,0XFF,0XFF,0XFF,0X7F,0X3F,0X1F,0X0F,0X07,0X03,
0X01,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X03,
0X01,0X01,0X01,0X01,0X01,0X03,0X07,0X1F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0XF8,
0XE0,0X00,0X00,0X00,0X00,0XF0,0XF8,0XFE,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XE7,0XE3,
0XE0,0XE0,0XE0,0XE0,0XE0,0XE0,0XE0,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XE0,0XE0,0XE0,0XE0,0XE0,0XE0,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XFF,
0XFF,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XC0,0XF0,0XF8,0XFC,0XFE,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XEF,0XE7,0XE3,0XE1,0XE0,0XE0,0XE0,0XE0,0XE0,0XE0,0XE0,
0XE0,0XE0,0XE0,0XE0,0XE0,0XE0,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0XE0,0XE0,0XE0,0XE0,0XE0,0XE0,0XE0,0XE0,0XE0,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X0E,0X7E,0XFE,0XFE,0XFE,0XFF,0XFF,0XFF,0XFF,0XFC,0XE0,0XC0,0XC0,
0X80,0X80,0X80,0X80,0XC0,0XC0,0XE0,0XF8,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X7F,
0X0F,0X00,0X00,0X00,0X00,0X1F,0X1F,0X1F,0X1F,0X1F,0X1F,0X1F,0X1F,0X1F,0X1F,0X1F,
0X1F,0X1F,0X1F,0X1F,0X1F,0X1F,0X1F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0X1F,0X1F,0X1F,0X1F,0X1F,0X1F,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XFF,
0XFF,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X3F,0X3F,0X3F,0X3F,0X3F,0X3F,0X3F,0X3F,0X3F,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X38,0X3F,0X3F,0X3F,0X3F,0X3F,0X3F,0X3F,
0X3F,0X3F,0X3F,0X3F,0X3F,0X3F,0X3F,0X3F,0X3F,0X3F,0X3F,0X3F,0X3F,0X3F,0X3F,0X3F,
0X3F,0X3F,0X3F,0X3F,0X3F,0X3F,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X3F,0X3F,0X3F,0X3F,0X3F,0X3F,0X3F,0X3F,0X3F,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X01,0X03,0X07,0X0F,0X1F,0X1F,0X3F,0X3F,0X3F,0X7F,0X7F,
0X7F,0X7F,0X7F,0X7F,0X7F,0X7F,0X3F,0X3F,0X3F,0X1F,0X0F,0X0F,0X07,0X03,0X01,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X3F,0X3F,0X3F,0X3F,0X3F,0X3F,0X3F,0X3F,0X3F,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XFF,
0XFF,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XFF,
0XFF,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X18,0X1C,0X0E,0X06,0X86,0XC6,0XFC,0X38,0X00,0XF0,0XFE,0X7E,0X66,0X66,0XE6,
0XC6,0X80,0X00,0X00,0X00,0X00,0X00,0XF8,0XFC,0X0E,0X06,0X06,0X0E,0XFC,0XF8,0X00,
0XF0,0XFC,0XCE,0X66,0X66,0XE6,0XCE,0X8C,0X00,0X00,0X00,0X00,0X00,0X18,0X1C,0X0E,
0X06,0X86,0XC6,0XFC,0X38,0X00,0XF8,0XFC,0X0E,0X06,0X06,0X0E,0XFC,0XF8,0X00,0X00,
0X30,0X18,0X0C,0XFE,0XFE,0X00,0X00,0X00,0X00,0X30,0X18,0X0C,0XFE,0XFE,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X38,0X7C,0X66,0XE6,0XC6,0XC6,0XCE,0X9C,0X18,0X00,0X00,0X60,0X70,0X30,
0XB0,0XB0,0XF0,0XE0,0X00,0X30,0XFC,0XFE,0X30,0X30,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XFF,
0XFF,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,
0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,
0X80,0X98,0X9C,0X9E,0X9B,0X9B,0X99,0X98,0X98,0X80,0X86,0X8E,0X9C,0X98,0X98,0X9C,
0X8F,0X87,0X80,0X80,0X98,0X98,0X80,0X87,0X8F,0X9C,0X98,0X98,0X9C,0X8F,0X87,0X80,
0X83,0X8F,0X9C,0X98,0X98,0X98,0X8F,0X87,0X80,0X80,0X98,0X98,0X80,0X98,0X9C,0X9E,
0X9B,0X9B,0X99,0X98,0X98,0X80,0X87,0X8F,0X9C,0X98,0X98,0X9C,0X8F,0X87,0X80,0X80,
0X80,0X80,0X80,0X9F,0X9F,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X9F,0X9F,0X80,0X80,
0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,
0X80,0X80,0X86,0X8E,0X9C,0X98,0X98,0X98,0X9D,0X8F,0X87,0X80,0X80,0X8E,0X9F,0X9B,
0X99,0X99,0X8F,0X9F,0X90,0X80,0X8F,0X9F,0X98,0X98,0X80,0X80,0X80,0X80,0X80,0X80,
0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,
0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0X80,0XFF,

};


unsigned char code pic4[4608] = { /* 0X32,0X02,0X00,0XC0,0X00,0X60, */
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X40,0X80,
0X80,0XD0,0XD0,0XE0,0XF0,0XF0,0XF4,0XF8,0XB8,0XBC,0X7C,0X3D,0X3E,0X3E,0X2E,0X2F,
0X1F,0X1F,0X0F,0X0F,0X0F,0X0B,0X0B,0X0B,0X07,0X07,0X07,0X07,0X03,0X03,0X03,0X03,
0X03,0X03,0X03,0X03,0X03,0X03,0X03,0X03,0X03,0X03,0X03,0X03,0X07,0X07,0X07,0X07,
0X0B,0X07,0X02,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X01,0X05,0X16,0X55,0X55,0X55,0XAA,0XAA,0XA0,0XF8,0XA4,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X01,0X14,0X64,0X55,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,0X47,
0X1B,0X02,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X40,0X80,0XC0,0XD0,0XE0,0XF0,0XF8,0XFC,0X7D,0X7D,0X2E,0X2F,0X1F,0X0F,
0X0B,0X07,0X03,0X03,0X02,0X01,0X01,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X01,0X05,0X55,0X56,0X5A,0X55,0X5A,0X55,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X40,0XA0,0XA4,0X69,0X59,0X5A,0XA9,0X90,0XA0,0X60,
0X60,0X60,0X50,0X00,0X00,0X00,0X05,0X54,0X40,0X00,0X50,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X40,0X55,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X40,0X40,0X00,0X00,0X00,0X00,0X00,0X00,
0X7D,0X3E,0X2F,0X1F,0X0B,0X07,0X03,0X02,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X40,0X40,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X05,0X55,0X55,0X69,0X01,0X00,0X00,
0X00,0X00,0X00,0X80,0XA0,0XA0,0XA9,0X6B,0X19,0X45,0X85,0X95,0X91,0X91,0X91,0X50,
0X54,0X50,0X54,0X69,0X00,0X00,0X00,0X00,0X15,0X58,0X01,0X00,0X00,0X00,0X00,0X00,
0X00,0X40,0XC0,0XD0,0XE0,0XE0,0XE0,0XD0,0X80,0X00,0X00,0X00,0X00,0X50,0X25,0X00,
0X00,0X90,0XA4,0XF8,0XF8,0X54,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X54,0XFD,0XFF,0XFF,0XFE,0XF9,0X90,0X00,0X00,0X19,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X40,0XE0,0XE0,0X40,0X90,0X90,0XA8,0XF9,0XBE,0X6F,0X93,0XA0,0XA4,0XF4,0XB8,0X2C,
0X18,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X05,0X1A,0X50,0X00,0X00,0X00,
0X00,0X50,0X69,0X56,0X05,0X41,0X95,0XE5,0XF9,0XFE,0XFF,0XFF,0XFF,0XAF,0XAA,0XAA,
0X4A,0X06,0X01,0X00,0X00,0X00,0X00,0X40,0XD0,0XE5,0XF4,0XB4,0XB4,0XB4,0XA0,0XE0,
0XA4,0X5A,0X5B,0X5A,0X5A,0X6A,0X6A,0XAB,0XBF,0XFD,0X80,0X90,0XE4,0XD6,0XD0,0X50,
0X05,0X0B,0X07,0X06,0X01,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X06,0X07,0X1B,0X1F,0X1F,0X1F,0X14,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X40,0XA4,0XB8,0X94,0X94,
0X56,0X6B,0X6A,0X65,0XAA,0XAA,0X6B,0X6A,0X6A,0X6A,0X5A,0X5B,0X56,0X56,0X15,0X15,
0X15,0X05,0X05,0X05,0X05,0X05,0X05,0X04,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X50,
0XF8,0XFD,0XF9,0XF8,0XA0,0X40,0X00,0X00,0X00,0X00,0X40,0XD0,0XD0,0X90,0X40,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,0X59,0X40,0X00,
0X00,0X00,0X15,0X50,0X94,0XA9,0XAA,0XBF,0XBF,0XAF,0XAF,0XAB,0X6A,0X66,0X6A,0X1A,
0X01,0X00,0X00,0X00,0X00,0X00,0XA4,0XFF,0XAB,0X6A,0X56,0X15,0X55,0X95,0X55,0X69,
0X66,0X5A,0X6D,0X19,0X6E,0X59,0X69,0X7A,0X9A,0X9B,0X16,0X45,0X56,0X5B,0XAA,0XAB,
0XFE,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,0X01,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XA4,0XFD,0XF8,0XA9,0XAA,0XAA,0X6A,0XBE,
0XFA,0XA5,0X95,0X55,0X15,0X15,0X05,0X05,0X05,0X01,0X01,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X07,0X1B,0X1F,0X2F,0X2F,0X55,0X40,0X00,0X00,0X00,0X1F,0X7F,0XBF,0XFF,0X55,0X00,
0X00,0X00,0X00,0X00,0XE4,0XF4,0XE4,0X90,0X00,0X00,0X00,0X00,0X00,0X00,0X16,0X90,
0X00,0X00,0X94,0X69,0X29,0X29,0X66,0X96,0X96,0X96,0XAA,0X69,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X01,0X9B,0XFE,0XFE,0XFD,0XFD,0XFE,0XFE,0XFD,0XF9,
0XF9,0XF5,0XE5,0X55,0X99,0XE5,0XF9,0XF9,0XFA,0XFA,0XFC,0XFD,0XF9,0XF9,0XFE,0X9B,
0X02,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0XA4,0XFC,0XF8,0XAA,0XBF,0XAF,0XAA,0XAA,0X6A,0X55,0X16,
0X1B,0X2F,0XBE,0XB9,0XF8,0XE4,0XE0,0XD0,0X90,0X80,0X80,0X40,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X05,0X14,0X14,0X10,0X20,0X20,0X40,0X41,0X94,0X00,
0X00,0X00,0X00,0X00,0X06,0X1B,0X2F,0X2A,0X40,0X00,0X00,0X00,0X00,0X00,0X00,0X16,
0XA8,0XA9,0X42,0X40,0X00,0X00,0X00,0X01,0X01,0X41,0X01,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X2A,0X7F,0XBF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XBF,0XAB,0XBF,0XBF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XBF,0X6F,0X1B,
0X01,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X54,0XBE,0XFD,0XEA,0XAF,0XBF,0XAE,0XAA,0XAA,0X6A,0X56,0X15,0X01,0X00,
0X00,0X00,0X00,0X40,0X91,0XE1,0XF6,0XFA,0XFA,0XFA,0XBF,0XBF,0XFE,0XFE,0XF9,0XA4,
0X50,0X40,0X50,0X50,0X40,0X40,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X05,0X05,
0X14,0X50,0X50,0X10,0X10,0X10,0X14,0X14,0X15,0X14,0X18,0X05,0X01,0X01,0X01,0X01,
0X16,0X6A,0X01,0X01,0X02,0X02,0X05,0X05,0X05,0X09,0X14,0X14,0X50,0X50,0X40,0X00,
0X00,0X50,0X40,0X00,0X00,0X00,0X00,0X00,0X00,0X01,0X02,0X46,0X57,0X46,0X46,0X92,
0X66,0X1A,0X05,0X01,0X41,0X91,0X91,0X92,0X42,0X02,0X02,0X02,0X01,0X01,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0XA8,0X69,0XAA,0X6A,0X6B,0X5A,0X5A,0X5A,0X56,0X55,0X45,0X80,0X40,0X40,0X40,
0X50,0X54,0XAA,0XAA,0XAF,0XAF,0XBF,0XBF,0XBF,0XAF,0XAF,0X6F,0X6B,0X1B,0X1A,0X06,
0X05,0X01,0X01,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X80,
0XE0,0XFA,0XF9,0XF8,0XF8,0XF8,0XA4,0X50,0X00,0X00,0X00,0X00,0X00,0X00,0X01,0X02,
0X05,0X6A,0XA5,0X80,0X40,0X40,0X00,0X00,0X00,0X00,0X00,0X05,0XAA,0X56,0X01,0X00,
0X00,0X00,0X00,0X00,0X05,0X6A,0XBA,0XAA,0XA5,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X69,0XFE,0XFE,0XE9,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X40,0X91,0X95,0XE5,0XF9,0XF9,0XFE,0XFE,0XFE,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0XFE,
0XFE,0XFE,0XFE,0XFA,0XFA,0XAA,0XAA,0X5A,0X55,0X05,0X55,0X55,0X40,0X10,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X40,0X90,0XE4,0XF8,0XF9,0XF9,0XF9,0XE8,0XA4,0X40,0X50,0XA9,0X1B,
0X06,0X01,0X01,0X02,0X07,0X0B,0X06,0X94,0XF8,0XF8,0XF8,0XE4,0X40,0X00,0X00,0X00,
0X00,0X00,0X00,0X01,0X01,0X02,0X06,0X09,0X28,0X64,0X90,0X80,0X9A,0X95,0X40,0X40,
0X40,0X40,0X40,0X00,0X00,0X00,0X01,0X06,0XA5,0X40,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X01,0X03,0X07,0X54,0X40,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X40,0X40,0X00,0X00,0X00,0X00,0X40,0X90,0XA4,0XE8,0XFA,
0XFE,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XBF,0XAF,0XEF,0XEF,0XAF,0XAF,0XAF,0XAF,0XAF,
0XBF,0XFF,0XBF,0XAF,0X6F,0X6F,0X1A,0X06,0X05,0X04,0X01,0X01,0X01,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X50,0XE4,0XF9,0XFE,0XFE,0XF9,
0XF9,0X94,0X40,0XA9,0X6E,0X07,0X07,0X6B,0X6F,0X7F,0X2B,0X06,0X01,0XAA,0X16,0X00,
0X54,0XA9,0XAA,0XA9,0X94,0X96,0XAA,0XAA,0X57,0X07,0X17,0X5F,0XAA,0X50,0X90,0XE4,
0XE4,0XE4,0X90,0X40,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X05,0X1A,0X1A,0X0A,0X0A,
0X0A,0X0A,0X0A,0X06,0X0A,0X0A,0X09,0X0A,0X1A,0X19,0X28,0X64,0XA0,0X90,0X90,0XA0,
0XA0,0XA4,0XA0,0XA0,0XA0,0X90,0XA6,0XA4,0X40,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X40,
0X40,0X40,0X40,0X80,0X90,0XE1,0XB5,0XB6,0XAA,0XEA,0XFA,0XFE,0XFE,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XBF,0XAF,0XAB,0XAA,0XEA,0XFE,0XFF,0XFF,0XFF,0XFF,0XFE,0XFE,0XFA,
0XEA,0XAA,0X5A,0X06,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XAA,0XAF,0X0B,0X0B,0X5B,0X1F,
0X1B,0X06,0X01,0X15,0X55,0X40,0X15,0X04,0X40,0X90,0XE0,0XE4,0XE4,0X56,0X00,0X40,
0XF9,0XFE,0XFF,0XFF,0XFF,0XBF,0XAA,0XAA,0XAA,0X50,0X40,0X55,0X16,0X05,0X1E,0X6F,
0X7F,0X7F,0XBF,0XA9,0X00,0X90,0XD0,0XE0,0XD0,0X90,0X40,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,0X01,0X01,0X00,
0X00,0X00,0X00,0X00,0X01,0X01,0X02,0X06,0X19,0X69,0XA4,0XA9,0X54,0X00,0X00,0X80,
0XD0,0XE0,0XB0,0XB0,0XB0,0XF0,0XD0,0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X40,0X40,0X50,0X50,0X54,0X54,0X94,0X95,0XA5,0XE9,0XE9,
0XE9,0XEE,0XBA,0XAA,0X7A,0X1E,0X1A,0X0B,0X87,0XA2,0X36,0X3E,0XAF,0XFF,0XFF,0XFF,
0XAF,0XAB,0XAA,0XFA,0XFA,0XAA,0XFF,0XFF,0XFF,0XBF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFE,0XF9,0XE4,0XE0,0X80,0X40,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X41,0X99,0X50,0X00,0X55,0X54,
0X40,0X00,0X00,0X00,0X01,0X15,0X14,0X40,0XAA,0XFF,0X5F,0X47,0X02,0X01,0X14,0X69,
0XFF,0XAB,0XAA,0XBF,0XFF,0XBA,0XAA,0X6A,0X55,0XA4,0XF9,0XF9,0XF8,0XF8,0XE4,0X91,
0X45,0X90,0X6A,0X06,0X05,0X2E,0XBF,0X7F,0XBF,0XFF,0XA9,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X40,0X80,0X81,0XD6,0XEA,0XE9,0XE9,0XFF,
0XAB,0X9A,0X56,0X56,0X56,0XAA,0XAA,0XFF,0X54,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X90,0X94,0X94,0X55,0X95,0X95,0XE5,0XE9,0XE9,0XF9,0XBE,0XFE,0XFF,0X2F,0X9F,0X7F,
0X0B,0X02,0X05,0X02,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X66,0XAA,0X6B,0X6B,0XAA,
0X6A,0X5A,0XAA,0XFF,0XBF,0XAF,0XBF,0XAF,0XAA,0XEA,0XFF,0XBF,0XBF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0XFE,0XF9,0XE4,0XA0,0X90,0X40,0X40,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X40,0XA4,0XF9,0XFE,0XFF,0XFF,0XFE,0X69,0X00,0X01,
0X05,0X05,0X54,0XE4,0XF8,0XFD,0XFE,0XFE,0XAA,0X0B,0X1A,0X24,0X50,0X10,0X10,0X11,
0X06,0X56,0X5A,0X1A,0X4B,0X0A,0X06,0X01,0X00,0X40,0X42,0X17,0X6F,0XFF,0XFF,0XBF,
0X05,0X01,0X00,0X40,0X10,0X54,0X55,0X95,0X69,0X1A,0X01,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0XF4,0XFE,0XAF,0X6B,0X6B,0X6B,0X6B,0X6B,0X6B,0XAA,
0XF9,0XB9,0X65,0XB9,0X69,0XA5,0XFA,0XAA,0X6A,0X6A,0X5B,0XAB,0XAB,0XAE,0XAD,0XF8,
0X96,0XAA,0XFA,0XFA,0XFE,0XFF,0X2F,0XFF,0X3F,0X03,0X15,0X0B,0X00,0X00,0X01,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X04,0X59,0X0A,0X06,0X06,0X06,0X01,
0X01,0X01,0X06,0X16,0X52,0X46,0X06,0X01,0X06,0X7F,0X2F,0X06,0X6A,0XBF,0XFF,0XAB,
0XBF,0XFF,0XFF,0XBF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0XFA,0XEA,0XA9,0XA4,
0XA4,0X90,0X50,0X40,0X40,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X15,0XBF,0XFF,0XAB,0X57,0XAB,0X42,0X00,0X00,0X00,
0X00,0X00,0X15,0X6F,0XFF,0XFF,0X97,0X02,0X04,0X00,0X00,0X00,0X00,0X40,0X40,0X54,
0X54,0X05,0X55,0X54,0X51,0X45,0X04,0X95,0XE4,0XA4,0X54,0X2D,0X1F,0X0B,0X06,0X01,
0X40,0X10,0X15,0X15,0X04,0X05,0X02,0X01,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X1F,0XBE,0XEA,0XE9,0X99,0XA5,0XA5,0X65,0X69,0XAE,
0X9E,0X55,0XA5,0XA9,0XA9,0X55,0X66,0X6D,0X69,0X95,0X95,0XA5,0XA5,0XA9,0XEA,0XFA,
0XFA,0X7F,0X0B,0X6B,0X2F,0X01,0X00,0X01,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X10,0X50,0X50,0X15,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X02,0X14,0X50,0X00,0X00,0X00,0X00,0X01,0X1A,0X6F,0X56,
0X06,0X6A,0XBF,0XFF,0XEA,0XAF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0XFB,0XFF,0XBF,0XFF,
0XFE,0XFA,0XEA,0XAA,0X6A,0XA9,0XA9,0XA4,0XA4,0XA4,0X90,0X80,0X40,0X40,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,0X1A,0X6E,0X69,0XA5,0X96,0X55,0X54,0X50,
0X50,0X50,0X40,0X40,0X42,0X43,0X97,0XDA,0X99,0X48,0X09,0X09,0X09,0X06,0X01,0X50,
0X54,0X05,0X91,0X81,0X85,0XD5,0XEA,0XFF,0XFF,0XFF,0XBA,0X00,0X00,0X00,0X54,0XBD,
0XFE,0XF9,0X54,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,0X92,0XFB,0XAE,0XAA,0X65,0X56,0X5B,
0X5B,0XB9,0XB9,0XA6,0XB9,0XA9,0X5B,0X5F,0X95,0XAA,0XAE,0XFE,0X8B,0X07,0X02,0X01,
0X1B,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X10,0X05,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X02,0X07,0X01,0X06,0X1B,0X6F,0XBF,0XAB,0X1B,0XAF,0XBF,0XFE,0XEA,
0X6B,0X7F,0XBF,0XFF,0XFD,0XF5,0XD1,0X42,0X07,0X0A,0X0A,0X0A,0X1A,0X1A,0X29,0X29,
0X29,0X29,0X28,0X28,0X24,0X14,0X14,0X04,0X00,0X00,0X00,0X01,0X01,0X02,0X06,0X06,
0X05,0X05,0X05,0X55,0XBE,0XFF,0XFF,0XBF,0X2F,0X16,0X50,0X10,0X44,0X45,0XA4,0X19,
0X06,0X40,0X01,0X06,0X5B,0X0B,0X0B,0X0B,0X1B,0X1B,0X11,0X10,0X11,0X11,0X14,0X1A,
0X1B,0X06,0X00,0X00,0X00,0X90,0XE4,0XB8,0XA9,0XA9,0X6A,0X5A,0XA9,0XA8,0X90,0X90,
0XA0,0XA0,0XA0,0XA0,0XA0,0X90,0X90,0X40,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X2F,0XFA,0XEA,0XAA,0XA5,0XA5,0X95,
0XE9,0XE9,0XBA,0X7A,0XEA,0XA9,0XA9,0X95,0XA5,0XA9,0XAA,0XFF,0X6E,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,0X02,0X00,0X00,0X00,0X02,0X03,
0X01,0X00,0X00,0X01,0X02,0X07,0X0B,0X0F,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X06,0X1A,0X2F,0X6F,0X7D,0X38,0X28,0X19,0X0A,0X06,0X00,0X00,
0X00,0X06,0X14,0X64,0X55,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X90,0XA4,
0X69,0X5A,0XAA,0XAA,0XAE,0X6A,0X6A,0X6A,0X56,0X56,0X55,0X56,0X55,0X46,0X96,0X46,
0X56,0X45,0X55,0X51,0X55,0X55,0X96,0XF9,0X54,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,0X03,0X07,0X0B,0X0F,0X0B,
0X07,0X02,0X01,0X00,0X57,0XAB,0X5F,0X0B,0X0A,0X0B,0X0B,0XA2,0X40,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X40,
0XE0,0XA8,0X58,0X58,0X04,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X40,0XD0,0X90,0XE0,0X90,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X15,0X66,0X59,0X04,0X00,0X00,0X00,0X00,0X00,0X00,0XA5,0XAA,0X55,
0X55,0X55,0X55,0X15,0X55,0X55,0XA5,0XE9,0XF9,0XFE,0XFE,0XFE,0XFE,0XFA,0XBA,0XAA,
0XAA,0XAA,0XAA,0X69,0X2A,0X1E,0X0A,0X06,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X55,0XEA,0XAA,0X55,0X00,0X00,0X00,0X55,0XFE,0X94,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X40,
0X80,0X80,0X90,0XE0,0XA0,0XA0,0XA0,0XA0,0X90,0X80,0X40,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X1A,
0XBA,0XA9,0X95,0X55,0X50,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XA4,0XAA,
0X5A,0X56,0X15,0X1A,0X1B,0X69,0X64,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X80,0XD0,0XB0,0XB0,0XB0,0XF0,
0XE0,0XD0,0X80,0X85,0XE6,0XE5,0XE0,0XE0,0XD0,0XD0,0X80,0X40,0X00,0X15,0X55,0X55,
0X15,0X41,0X55,0X55,0XA9,0XAA,0XFF,0XFF,0XFF,0XFF,0XBF,0XAF,0XAF,0XAA,0XAA,0XA6,
0XA6,0XAA,0X6E,0X05,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X54,0XFF,0XFA,0XF9,0XF8,0XF8,0XF4,0XF9,0XEF,0XEA,0XA4,0X90,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X50,0XA4,0XB9,0XAA,
0X97,0X96,0XAA,0XAA,0XAA,0XA9,0XE5,0XEA,0XFE,0XFA,0XFA,0XA5,0X40,0X00,0X00,0X01,
0X9A,0XA9,0X00,0X40,0X90,0X90,0X50,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0XF5,0XFB,0XAA,0XA9,0XA5,0X54,0X50,0X40,0X00,0X00,0X00,0X00,0X68,0XED,0XAB,0X6A,
0X55,0X00,0X00,0X00,0X00,0X00,0X00,0X40,0X80,0XC0,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X40,0X80,0X99,0XFF,0XAB,0XAA,0XAA,0XAA,0X6A,
0X6A,0X6B,0XAB,0XAF,0X6B,0X6A,0X5A,0X5A,0X5A,0X5A,0X6B,0XAB,0XBE,0XBD,0XE5,0X91,
0X04,0X55,0X55,0X6A,0XAA,0XAA,0XAB,0XAB,0X6A,0X6A,0X9A,0X9A,0XAA,0XAA,0X51,0X01,
0X00,0X00,0X00,0X00,0X40,0X80,0X90,0XD0,0XD0,0X80,0X40,0X00,0X40,0X40,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X02,0X02,0X02,0X02,0X02,0X02,0X02,0X02,0X03,0X07,0X0B,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X50,0X40,0X00,0X00,0X05,0X6A,0XBF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XAA,0X6A,0X16,0X00,0X40,0X80,0X65,
0X6A,0X96,0XA5,0X7A,0X2F,0X06,0X01,0X00,0X40,0X40,0X80,0X80,0X40,0X00,0X00,0X00,
0X07,0X2F,0X3E,0XBA,0XAA,0XF5,0XA5,0XA5,0XA5,0XA4,0X50,0X50,0X40,0X07,0X2E,0XA9,
0XA5,0X54,0X80,0X00,0X00,0XE4,0XBD,0X6B,0X9B,0X6B,0XAA,0XA8,0XAD,0X6D,0X6D,0X6D,
0XB8,0XA4,0X40,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X50,0XA8,0X69,0X5B,0X5B,0X56,0X5A,0X5A,0X5A,0X56,0X95,0X95,
0XA5,0XA5,0XE5,0XE5,0XE9,0XE9,0XE9,0XE5,0XA5,0X95,0X95,0X55,0X56,0X6A,0XAB,0XFF,
0XA9,0X55,0X95,0X65,0X29,0X1A,0X1A,0X1A,0X0A,0X0A,0X0A,0X0A,0X06,0X01,0X00,0X00,
0X00,0X00,0X00,0X69,0X56,0X56,0X55,0X55,0X5A,0XAA,0XAA,0XAA,0X5A,0X5A,0X6A,0XA4,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X04,0X55,0X55,0X64,0X90,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X40,0X80,0X40,0X80,0X40,0X40,0X05,0X15,0X54,0X50,0X40,0X00,0X06,0X1A,
0X6B,0X6B,0X6F,0XAF,0X7F,0XBF,0X6F,0X1B,0X56,0X55,0X05,0X14,0X05,0X05,0X05,0X05,
0X42,0X41,0X90,0XD0,0XE0,0XF4,0XB8,0X79,0X3E,0X1F,0X0B,0X07,0X01,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,0X0B,0X0E,0X19,0X19,0X19,0X15,0X15,0X05,
0X06,0XF9,0XBE,0XBD,0XBE,0XFF,0XAA,0X6A,0X69,0X6A,0X56,0X81,0X41,0X40,0X01,0X01,
0X01,0X0A,0X05,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X06,0X6A,0XA9,0X95,0X99,0XA5,0XA5,0XA9,0XA9,0XAA,0XAA,0XAA,
0XBB,0XAF,0XAF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0XFA,0XE9,0X95,0X56,0X5A,
0X6A,0X65,0X01,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X01,0X00,0X00,0X00,0X01,0X01,0X05,0X55,0X55,0X55,0X55,0XA5,0XAA,
0X80,0X40,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X40,0X55,0X55,0XA5,0X6A,0X05,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X01,0X02,0X0B,0X0B,0X0E,0X1E,0X2E,0X2D,0X2D,0X2D,0X2D,0X19,0X59,0X55,
0X55,0X59,0X55,0XE5,0X6A,0X06,0X05,0X04,0X14,0X24,0X61,0X51,0X82,0XA5,0X46,0X02,
0X02,0X16,0X66,0X82,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X40,0X80,0X80,0X90,0X90,0X80,0X80,0X40,
0X45,0XFB,0XAA,0X56,0X56,0X5A,0X06,0X01,0X00,0X00,0X00,0X01,0X01,0X2A,0X19,0X14,
0XA0,0X80,0X40,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X01,0X02,0X06,0X06,0X06,0X07,0X07,0X07,0X6B,0XFB,
0XEA,0XEA,0XEA,0XFE,0XFF,0XAF,0XAF,0XAF,0XAF,0XBF,0XBF,0XBF,0XAB,0XAA,0X59,0X55,
0X55,0X15,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X55,0X5A,0X6A,0X65,0X5A,
0X56,0XAA,0XA4,0X00,0X00,0X00,0X00,0X00,0X40,0X54,0X55,0X55,0X5A,0XAA,0XA5,0XF4,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
};

